# DPRK - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [DPRK](https://vuldb.com/?actor.dprk). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.dprk](https://vuldb.com/?actor.dprk)

## Campaigns

The following _campaigns_ are known and can be associated with DPRK:

* AppleJeus
* BLINDINGCAN
* DrillMalware
* ...

There are 3 more campaign items available. Please use our online service to access the data.

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with DPRK:

* [HK](https://vuldb.com/?country.hk)
* [US](https://vuldb.com/?country.us)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of DPRK.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.62.56.160](https://vuldb.com/?ip.5.62.56.160) | r-160.56.62.5.ptr.avast.com | - | High
2 | [5.62.56.161](https://vuldb.com/?ip.5.62.56.161) | r-161.56.62.5.ptr.avast.com | - | High
3 | [5.62.56.162](https://vuldb.com/?ip.5.62.56.162) | r-162.56.62.5.ptr.avast.com | - | High
4 | [5.62.56.163](https://vuldb.com/?ip.5.62.56.163) | r-163.56.62.5.ptr.avast.com | - | High
5 | [5.62.61.64](https://vuldb.com/?ip.5.62.61.64) | r-64.61.62.5.ptr.avast.com | - | High
6 | [5.62.61.65](https://vuldb.com/?ip.5.62.61.65) | r-65.61.62.5.ptr.avast.com | - | High
7 | [5.62.61.66](https://vuldb.com/?ip.5.62.61.66) | r-66.61.62.5.ptr.avast.com | - | High
8 | [5.62.61.67](https://vuldb.com/?ip.5.62.61.67) | r-67.61.62.5.ptr.avast.com | - | High
9 | [14.140.116.172](https://vuldb.com/?ip.14.140.116.172) | 14-140-116-172-sapient.com | Hoplight | High
10 | [21.252.107.198](https://vuldb.com/?ip.21.252.107.198) | - | HOPLIGHT | High
11 | [26.165.218.44](https://vuldb.com/?ip.26.165.218.44) | - | HOPLIGHT | High
12 | [45.33.2.79](https://vuldb.com/?ip.45.33.2.79) | li956-79.members.linode.com | AppleJeus | High
13 | [45.33.23.183](https://vuldb.com/?ip.45.33.23.183) | li977-183.members.linode.com | AppleJeus | High
14 | [45.42.151.0](https://vuldb.com/?ip.45.42.151.0) | - | - | High
15 | [45.42.151.11](https://vuldb.com/?ip.45.42.151.11) | - | - | High
16 | [45.42.151.12](https://vuldb.com/?ip.45.42.151.12) | - | - | High
17 | [45.42.151.13](https://vuldb.com/?ip.45.42.151.13) | - | - | High
18 | [45.42.151.14](https://vuldb.com/?ip.45.42.151.14) | - | - | High
19 | [45.56.79.23](https://vuldb.com/?ip.45.56.79.23) | li929-23.members.linode.com | AppleJeus | High
20 | [45.79.19.196](https://vuldb.com/?ip.45.79.19.196) | li1118-196.members.linode.com | AppleJeus | High
21 | [45.199.63.220](https://vuldb.com/?ip.45.199.63.220) | - | AppleJeus | High
22 | [46.36.203.81](https://vuldb.com/?ip.46.36.203.81) | - | - | High
23 | [46.36.203.82](https://vuldb.com/?ip.46.36.203.82) | - | - | High
24 | [47.206.4.145](https://vuldb.com/?ip.47.206.4.145) | static-47-206-4-145.srst.fl.frontiernet.net | HOPLIGHT | High
25 | [51.68.152.96](https://vuldb.com/?ip.51.68.152.96) | ns3122934.ip-51-68-152.eu | BLINDINGCAN | High
26 | [54.241.91.49](https://vuldb.com/?ip.54.241.91.49) | ec2-54-241-91-49.us-west-1.compute.amazonaws.com | BLINDINGCAN | Medium
27 | [57.73.224.0](https://vuldb.com/?ip.57.73.224.0) | - | - | High
28 | ... | ... | ... | ...

There are 109 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _DPRK_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1008 | CWE-757 | Algorithm Downgrade | High
2 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
3 | T1068 | CWE-250, CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
4 | ... | ... | ... | ...

There are 9 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by DPRK. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/09/business/upgrade/upcfgAction.php?download=true` | High
3 | File | `/admin-panel1.php` | High
4 | File | `/admin/academic/studenview_left.php` | High
5 | File | `/ad_js.php` | Medium
6 | File | `/alerts/alertConfigField.php` | High
7 | File | `/api/email_accounts` | High
8 | File | `/API/system/admins/session` | High
9 | File | `/cgi-bin/ExportALLSettings.sh` | High
10 | File | `/config/config.php` | High
11 | File | `/context/%2e/WEB-INF/web.xml` | High
12 | File | `/customers/index.php` | High
13 | File | `/DataHandler/AM/AM_Handler.ashx` | High
14 | File | `/DataHandler/HandlerAlarmGroup.ashx` | High
15 | File | `/DataHandler/HandlerEnergyType.ashx` | High
16 | File | `/DataHandler/Handler_CFG.ashx` | High
17 | File | `/ECT_Provider/` | High
18 | File | `/fuel/index.php/fuel/logs/items` | High
19 | File | `/fuel/index.php/fuel/pages/items` | High
20 | File | `/goform/openSchedWifi` | High
21 | File | `/goform/SetNetControlList` | High
22 | File | `/image_zoom.php` | High
23 | File | `/include/config.cache.php` | High
24 | File | `/json/profile/removeStarAjax.do` | High
25 | File | `/oauth/token/request` | High
26 | File | `/plugin/ajax.php` | High
27 | File | `/plugins/servlet/branchreview` | High
28 | File | `/proc/ioports` | High
29 | File | `/proc/self/exe` | High
30 | File | `/public/plugins/` | High
31 | File | `/rest/api/2/search` | High
32 | File | `/rest/api/latest/groupuserpicker` | High
33 | File | `/rest/api/latest/projectvalidate/key` | High
34 | File | `/rom-0` | Low
35 | ... | ... | ...

There are 304 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* http://blog.trendmicro.co.jp/archives/16218
* https://en.wikipedia.org/wiki/Internet_in_North_Korea#IP_address_ranges
* https://github.com/blackorbird/APT_REPORT/tree/master/International%20Strategic/Korea
* https://github.com/mandatoryprogrammer/NorthKoreaDNSLeak
* https://raidforums.com/Thread-North-Korean-IP-Addresses-300
* https://stairwell.com/wp-content/uploads/2022/04/Stairwell-threat-report-The-ink-stained-trail-of-GOLDBACKDOOR.pdf
* https://us-cert.cisa.gov/ncas/alerts/aa21-048a
* https://us-cert.cisa.gov/ncas/analysis-reports/AR19-100A
* https://us-cert.cisa.gov/ncas/analysis-reports/ar20-232a
* https://www.cisa.gov/uscert/ncas/analysis-reports/ar20-045g
* https://www.threatminer.org/report.php?q=HPSRSecurityBriefing_Episode16_NorthKorea.pdf&y=2014
* https://www.threatminer.org/report.php?q=SuspectedNorthKoreanCyberEspionageCampaignTargetsMultipleForeignMinistriesandThinkTanks.pdf&y=2019

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
