# Ursnif - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Ursnif](https://vuldb.com/?actor.ursnif). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.ursnif](https://vuldb.com/?actor.ursnif)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Ursnif:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)
* [ES](https://vuldb.com/?country.es)
* ...

There are 26 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Ursnif.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.56.73.146](https://vuldb.com/?ip.5.56.73.146) | host-static-5-56-73-146.moldtelecom.md | - | High
2 | [5.134.119.57](https://vuldb.com/?ip.5.134.119.57) | - | - | High
3 | [5.252.179.21](https://vuldb.com/?ip.5.252.179.21) | no-rdns.mivocloud.com | - | High
4 | [8.249.225.254](https://vuldb.com/?ip.8.249.225.254) | - | - | High
5 | [8.249.231.254](https://vuldb.com/?ip.8.249.231.254) | - | - | High
6 | [8.253.45.214](https://vuldb.com/?ip.8.253.45.214) | - | - | High
7 | [13.107.21.200](https://vuldb.com/?ip.13.107.21.200) | - | - | High
8 | [13.107.42.16](https://vuldb.com/?ip.13.107.42.16) | - | - | High
9 | [13.109.156.118](https://vuldb.com/?ip.13.109.156.118) | dfw.4.0p1b00000008osacau.00db0000000z3sfeak.gslb.siteforce.com | - | High
10 | [20.42.65.92](https://vuldb.com/?ip.20.42.65.92) | - | - | High
11 | [20.189.173.20](https://vuldb.com/?ip.20.189.173.20) | - | - | High
12 | [20.189.173.22](https://vuldb.com/?ip.20.189.173.22) | - | - | High
13 | [23.3.13.88](https://vuldb.com/?ip.23.3.13.88) | a23-3-13-88.deploy.static.akamaitechnologies.com | - | High
14 | [23.3.13.154](https://vuldb.com/?ip.23.3.13.154) | a23-3-13-154.deploy.static.akamaitechnologies.com | - | High
15 | [23.41.181.230](https://vuldb.com/?ip.23.41.181.230) | a23-41-181-230.deploy.static.akamaitechnologies.com | - | High
16 | [23.41.182.96](https://vuldb.com/?ip.23.41.182.96) | a23-41-182-96.deploy.static.akamaitechnologies.com | - | High
17 | [23.54.215.147](https://vuldb.com/?ip.23.54.215.147) | a23-54-215-147.deploy.static.akamaitechnologies.com | - | High
18 | [23.202.231.167](https://vuldb.com/?ip.23.202.231.167) | a23-202-231-167.deploy.static.akamaitechnologies.com | - | High
19 | [23.221.49.75](https://vuldb.com/?ip.23.221.49.75) | a23-221-49-75.deploy.static.akamaitechnologies.com | - | High
20 | [23.221.50.102](https://vuldb.com/?ip.23.221.50.102) | a23-221-50-102.deploy.static.akamaitechnologies.com | - | High
21 | [23.221.50.122](https://vuldb.com/?ip.23.221.50.122) | a23-221-50-122.deploy.static.akamaitechnologies.com | - | High
22 | [31.13.65.174](https://vuldb.com/?ip.31.13.65.174) | instagram-p42-shv-01-atl3.fbcdn.net | - | High
23 | [37.187.0.40](https://vuldb.com/?ip.37.187.0.40) | ns3108067.ip-37-187-0.eu | - | High
24 | [38.126.130.202](https://vuldb.com/?ip.38.126.130.202) | action-s.pipelane.net | - | High
25 | ... | ... | ... | ...

There are 96 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Ursnif_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-266, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-307, CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 5 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Ursnif. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/?module=users&section=cpanel&page=list` | High
2 | File | `/admin/powerline` | High
3 | File | `/admin/syslog` | High
4 | File | `/api/upload` | Medium
5 | File | `/app/Http/Controllers/Admin/NEditorController.php` | High
6 | File | `/cgi-bin` | Medium
7 | File | `/cgi-bin/kerbynet` | High
8 | File | `/context/%2e/WEB-INF/web.xml` | High
9 | File | `/dcim/sites/add/` | High
10 | File | `/EXCU_SHELL` | Medium
11 | File | `/forum/away.php` | High
12 | File | `/fudforum/adm/hlplist.php` | High
13 | File | `/login` | Low
14 | File | `/Main_Login.asp?flag=1&productname=RT-AC88U&url=/downloadmaster/task.asp` | High
15 | File | `/monitoring` | Medium
16 | File | `/new` | Low
17 | File | `/proc/<pid>/status` | High
18 | File | `/public/plugins/` | High
19 | File | `/rom` | Low
20 | File | `/scripts/killpvhost` | High
21 | File | `/secure/admin/InsightDefaultCustomFieldConfig.jspa` | High
22 | File | `/secure/QueryComponent!Default.jspa` | High
23 | File | `/src/main/java/com/dotmarketing/filters/CMSFilter.java` | High
24 | File | `/tmp` | Low
25 | File | `/tmp/redis.ds` | High
26 | File | `/uncpath/` | Medium
27 | File | `/ViewUserHover.jspa` | High
28 | File | `/wp-admin` | Medium
29 | File | `/wp-json/wc/v3/webhooks` | High
30 | File | `14all.cgi/14all-1.1.cgi/traffic.cgi/mrtg.cgi` | High
31 | File | `AccountManagerService.java` | High
32 | File | `actions/CompanyDetailsSave.php` | High
33 | File | `ActiveServices.java` | High
34 | File | `ActivityManagerService.java` | High
35 | File | `adclick.php` | Medium
36 | File | `addlink.php` | Medium
37 | File | `addtocart.asp` | High
38 | ... | ... | ...

There are 328 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2018/12/threat-roundup-1214-1221.html
* https://blog.talosintelligence.com/2019/03/threat-roundup-0315-0322.html
* https://blog.talosintelligence.com/2019/06/threat-roundup-0614-0621.html
* https://blog.talosintelligence.com/2019/07/threat-roundup-0712-0719.html
* https://blog.talosintelligence.com/2019/08/threat-roundup-0726-0802.html
* https://blog.talosintelligence.com/2019/08/threat-roundup-0823-0830.html
* https://blog.talosintelligence.com/2021/04/threat-roundup-0402-0409.html
* https://blog.talosintelligence.com/2021/08/threat-roundup-0806-0813.html
* https://blog.talosintelligence.com/2022/04/threat-roundup-0408-0415.html
* https://isc.sans.edu/forums/diary/German+language+malspam+pushes+Ursnif/25732/
* https://isc.sans.edu/forums/diary/Malpsam+pushes+Ursnif+through+Italian+language+Word+docs/25792/
* https://isc.sans.edu/forums/diary/Ursnif+infection+with+Dridex/25566/
* https://pastebin.com/06gwfSzu

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
