# Rocket Kitten - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Rocket Kitten_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Rocket Kitten:

* [US](https://vuldb.com/?country.us)
* [IR](https://vuldb.com/?country.ir)
* [ES](https://vuldb.com/?country.es)
* ...

There are 7 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with Rocket Kitten or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Magic Hound](https://vuldb.com/?actor.magic_hound) | High
2 | [Rocket Kitten](https://vuldb.com/?actor.rocket_kitten) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Rocket Kitten.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [5.39.223.227](https://vuldb.com/?ip.5.39.223.227) | - | [Magic Hound](https://vuldb.com/?actor.magic_hound) | High
2 | [5.145.151.1](https://vuldb.com/?ip.5.145.151.1) | ip-5-145-151-1.hosts.businesscomnetworks.com | [Magic Hound](https://vuldb.com/?actor.magic_hound) | High
3 | [5.145.151.2](https://vuldb.com/?ip.5.145.151.2) | ip-5-145-151-2.hosts.businesscomnetworks.com | [Magic Hound](https://vuldb.com/?actor.magic_hound) | High
4 | [5.145.151.3](https://vuldb.com/?ip.5.145.151.3) | ip-5-145-151-3.hosts.businesscomnetworks.com | [Magic Hound](https://vuldb.com/?actor.magic_hound) | High
5 | [5.145.151.4](https://vuldb.com/?ip.5.145.151.4) | ip-5-145-151-4.hosts.businesscomnetworks.com | [Magic Hound](https://vuldb.com/?actor.magic_hound) | High
6 | [5.145.151.5](https://vuldb.com/?ip.5.145.151.5) | ip-5-145-151-5.hosts.businesscomnetworks.com | [Magic Hound](https://vuldb.com/?actor.magic_hound) | High
7 | [5.145.151.6](https://vuldb.com/?ip.5.145.151.6) | ip-5-145-151-6.hosts.businesscomnetworks.com | [Magic Hound](https://vuldb.com/?actor.magic_hound) | High
8 | [5.145.151.7](https://vuldb.com/?ip.5.145.151.7) | ip-5-145-151-7.hosts.businesscomnetworks.com | [Magic Hound](https://vuldb.com/?actor.magic_hound) | High
9 | [31.192.105.10](https://vuldb.com/?ip.31.192.105.10) | - | [Magic Hound](https://vuldb.com/?actor.magic_hound) | High
10 | [83.170.33.37](https://vuldb.com/?ip.83.170.33.37) | host-83-170-33-37.customer.teleport-iabg.de | [Rocket Kitten](https://vuldb.com/?actor.rocket_kitten) | High
11 | [83.170.33.60](https://vuldb.com/?ip.83.170.33.60) | host-83-170-33-60.customer.teleport-iabg.de | [Rocket Kitten](https://vuldb.com/?actor.rocket_kitten) | High
12 | [83.170.33.80](https://vuldb.com/?ip.83.170.33.80) | host-83-170-33-80.customer.teleport-iabg.de | [Rocket Kitten](https://vuldb.com/?actor.rocket_kitten) | High
13 | [83.170.43.67](https://vuldb.com/?ip.83.170.43.67) | host-83-170-43-67.customer.teleport-iabg.de | [Rocket Kitten](https://vuldb.com/?actor.rocket_kitten) | High
14 | [84.11.75.220](https://vuldb.com/?ip.84.11.75.220) | host-84-11-75-220.customer.teleport-iabg.de | [Rocket Kitten](https://vuldb.com/?actor.rocket_kitten) | High
15 | [84.11.146.52](https://vuldb.com/?ip.84.11.146.52) | host-84-11-146-52.customer.teleport-iabg.de | [Magic Hound](https://vuldb.com/?actor.magic_hound) | High
16 | [84.11.146.53](https://vuldb.com/?ip.84.11.146.53) | host-84-11-146-53.customer.teleport-iabg.de | [Magic Hound](https://vuldb.com/?actor.magic_hound) | High
17 | [84.11.146.54](https://vuldb.com/?ip.84.11.146.54) | host-84-11-146-54.customer.teleport-iabg.de | [Magic Hound](https://vuldb.com/?actor.magic_hound) | High
18 | [84.11.146.55](https://vuldb.com/?ip.84.11.146.55) | host-84-11-146-55.customer.teleport-iabg.de | [Magic Hound](https://vuldb.com/?actor.magic_hound) | High
19 | ... | ... | ... | ...

There are 73 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Rocket Kitten. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 6 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Rocket Kitten. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/admin.php` | Medium
3 | File | `/admin/book/create/` | High
4 | File | `/admin/loginc.php` | High
5 | File | `/auditLogAction.do` | High
6 | File | `/cgi-bin/wapopen` | High
7 | File | `/devices/acurite.c` | High
8 | File | `/etc/ajenti/config.yml` | High
9 | File | `/etc/sudoers` | Medium
10 | File | `/example/editor` | High
11 | File | `/getcfg.php` | Medium
12 | File | `/GetCSSashx/?CP=%2fwebconfig` | High
13 | File | `/goform/login_process` | High
14 | File | `/goform/rlmswitchr_process` | High
15 | File | `/goforms/rlminfo` | High
16 | File | `/plugin` | Low
17 | File | `/rating.php` | Medium
18 | File | `/scas/admin/` | Medium
19 | File | `/scas/classes/Users.php?f=save_user` | High
20 | File | `/services/prefs.php` | High
21 | File | `/src/njs_object.c` | High
22 | File | `/uncpath/` | Medium
23 | File | `/wordpress-gallery-transformation/gallery.php` | High
24 | File | `adclick.php` | Medium
25 | ... | ... | ...

There are 209 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://blog.checkpoint.com/wp-content/uploads/2015/11/rocket-kitten-report.pdf
* https://isc.sans.edu/forums/diary/Rocket+Kitten+Is+it+still+APT+if+you+can+buy+it+off+the+shelf/19123/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
