# Agent Tesla - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Agent Tesla](https://vuldb.com/?actor.agent_tesla). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.agent_tesla](https://vuldb.com/?actor.agent_tesla)

## Campaigns

The following _campaigns_ are known and can be associated with Agent Tesla:

* Phishing Korea

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Agent Tesla:

* [US](https://vuldb.com/?country.us)
* [GB](https://vuldb.com/?country.gb)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 11 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Agent Tesla.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [31.3.251.197](https://vuldb.com/?ip.31.3.251.197) | h31-3-251-197.host.redstation.co.uk | - | High
2 | [69.174.99.181](https://vuldb.com/?ip.69.174.99.181) | unassigned.quadranet.com | Phishing Korea | High
3 | [103.147.185.68](https://vuldb.com/?ip.103.147.185.68) | - | - | High
4 | ... | ... | ... | ...

There are 14 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Agent Tesla_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 3 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Agent Tesla. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/api/addusers` | High
3 | File | `/cgi-bin/wapopen` | High
4 | File | `/etc/ajenti/config.yml` | High
5 | File | `/goform/telnet` | High
6 | File | `/include/chart_generator.php` | High
7 | File | `/modules/profile/index.php` | High
8 | File | `/public/login.htm` | High
9 | File | `/rom-0` | Low
10 | File | `/tmp/phpglibccheck` | High
11 | File | `/uncpath/` | Medium
12 | File | `/usr/local/nagiosxi/html/includes/configwizards/windowswmi/windowswmi.inc.php` | High
13 | File | `/var/log/nginx` | High
14 | File | `/var/tmp/sess_*` | High
15 | File | `action.php` | Medium
16 | File | `actionphp/download.File.php` | High
17 | File | `add_comment.php` | High
18 | File | `admin.a6mambocredits.php` | High
19 | File | `admin.php` | Medium
20 | File | `admin/admin.php` | High
21 | File | `admin/content.php` | High
22 | File | `admin/index.php?id=users/action=edit/user_id=1` | High
23 | File | `admin/memberviewdetails.php` | High
24 | File | `admin/sitesettings.php` | High
25 | File | `affich.php` | Medium
26 | File | `agent/Core/Controller/SendRequest.cpp` | High
27 | File | `akeyActivationLogin.do` | High
28 | File | `album_portal.php` | High
29 | File | `apache-auth.conf` | High
30 | File | `askapache-firefox-adsense.php` | High
31 | File | `attachment.cgi` | High
32 | File | `blueprints/sections/edit/1` | High
33 | File | `books.php` | Medium
34 | File | `cart_add.php` | Medium
35 | File | `category.cfm` | Medium
36 | File | `CFS.c` | Low
37 | File | `cgi-bin/gnudip.cgi` | High
38 | File | `checktransferstatus.php` | High
39 | File | `checkuser.php` | High
40 | File | `class.SystemAction.php` | High
41 | File | `clientarea.php` | High
42 | File | `cmdmon.c` | Medium
43 | File | `collectivite.class.php` | High
44 | File | `confirm.php` | Medium
45 | File | `contact` | Low
46 | File | `control.c` | Medium
47 | ... | ... | ...

There are 405 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blogs.blackberry.com/en/2020/04/threat-spotlight-secret-agent-tesla
* https://github.com/netskopeoss/NetskopeThreatLabsIOCs/tree/main/AgentTesla/IOCs
* https://services.global.ntt/en-us/insights/blog/discovering-a-new-agent-tesla-malware-sample
* https://www.fortinet.com/blog/threat-research/phishing-campaign-targeting-korean-to-deliver-agent-tesla-new-variant

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
