# Angler Exploit Kit - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Angler Exploit Kit](https://vuldb.com/?actor.angler_exploit_kit). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.angler_exploit_kit](https://vuldb.com/?actor.angler_exploit_kit)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Angler Exploit Kit:

* [ES](https://vuldb.com/?country.es)
* [DE](https://vuldb.com/?country.de)
* [AR](https://vuldb.com/?country.ar)
* ...

There are 8 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Angler Exploit Kit.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [46.30.46.38](https://vuldb.com/?ip.46.30.46.38) | free.eurobyte.ru | - | High
2 | [50.62.123.1](https://vuldb.com/?ip.50.62.123.1) | p3nlhg674c1674.shr.prod.phx3.secureserver.net | - | High
3 | [62.221.204.114](https://vuldb.com/?ip.62.221.204.114) | v21009.2is.nl | - | High
4 | [69.162.64.156](https://vuldb.com/?ip.69.162.64.156) | 156-64-162-69.static.reverse.lstn.net | - | High
5 | [69.162.64.158](https://vuldb.com/?ip.69.162.64.158) | 158-64-162-69.static.reverse.lstn.net | - | High
6 | [69.162.86.36](https://vuldb.com/?ip.69.162.86.36) | 36-86-162-69.static.reverse.lstn.net | - | High
7 | [69.162.90.107](https://vuldb.com/?ip.69.162.90.107) | 107-90-162-69.static.reverse.lstn.net | - | High
8 | [69.162.116.123](https://vuldb.com/?ip.69.162.116.123) | 123-116-162-69.static.reverse.lstn.net | - | High
9 | [69.162.116.125](https://vuldb.com/?ip.69.162.116.125) | 125-116-162-69.static.reverse.lstn.net | - | High
10 | [75.103.83.9](https://vuldb.com/?ip.75.103.83.9) | - | - | High
11 | ... | ... | ... | ...

There are 39 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Angler Exploit Kit_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1211 | CWE-254, CWE-358 | 7PK Security Features | High
4 | ... | ... | ... | ...

There are 1 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Angler Exploit Kit. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/index.php` | High
2 | File | `/download` | Medium
3 | File | `/find_v2/_click` | High
4 | File | `/forum/away.php` | High
5 | File | `/horde/util/go.php` | High
6 | File | `/modules/profile/index.php` | High
7 | File | `/oauth/logout?redirect=url` | High
8 | File | `/out.php` | Medium
9 | File | `/redirect?url` | High
10 | File | `/replication` | Medium
11 | File | `/setup/finish` | High
12 | File | `adclick.php` | Medium
13 | File | `add2.php` | Medium
14 | File | `admin.jcomments.php` | High
15 | File | `admin/admin_users.php` | High
16 | File | `admin/changedata.php` | High
17 | File | `admin/conf_users_edit.php` | High
18 | ... | ... | ...

There are 143 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2015/02/angler-exploit-kit-new-variants.html
* https://blog.talosintelligence.com/2015/06/angler-ek-more-obfuscation-fake.html
* https://blog.talosintelligence.com/2016/03/angler-slips-hook.html
* https://blog.talosintelligence.com/2016/05/angler-phish.html
* https://blog.talosintelligence.com/2016/05/spin-to-win-malware.html
* https://blog.talosintelligence.com/2019/06/spelevo-exploit-kit.html
* https://isc.sans.edu/forums/diary/Angler+exploit+kit+pushing+CryptoWall+30/19737/
* https://isc.sans.edu/forums/diary/Anglers+best+friends/19959/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
