# Barys - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Barys](https://vuldb.com/?actor.barys). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.barys](https://vuldb.com/?actor.barys)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Barys:

* [US](https://vuldb.com/?country.us)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Barys.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [13.107.21.200](https://vuldb.com/?ip.13.107.21.200) | - | - | High
2 | [13.107.22.200](https://vuldb.com/?ip.13.107.22.200) | - | - | High
3 | [23.225.145.234](https://vuldb.com/?ip.23.225.145.234) | - | - | High
4 | [47.246.136.160](https://vuldb.com/?ip.47.246.136.160) | - | - | High
5 | [52.137.90.34](https://vuldb.com/?ip.52.137.90.34) | - | - | High
6 | [52.185.71.28](https://vuldb.com/?ip.52.185.71.28) | - | - | High
7 | [58.215.145.95](https://vuldb.com/?ip.58.215.145.95) | - | - | High
8 | ... | ... | ... | ...

There are 30 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Barys_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1211 | CWE-254, CWE-358 | 7PK Security Features | High
4 | ... | ... | ... | ...

There are 1 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Barys. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `$HOME/.cdrdao` | High
2 | File | `.FBCIndex` | Medium
3 | File | `/cgi-bin` | Medium
4 | File | `/cgi/cpaddons_feature.pl` | High
5 | File | `/dana/nc/ncrun.cgi` | High
6 | File | `/firewall/policy/` | High
7 | File | `/help/helpredir.aspx` | High
8 | File | `/irj/portal/` | Medium
9 | File | `/proc` | Low
10 | File | `/proc/net/ip6_flowlabel` | High
11 | File | `/search` | Low
12 | File | `/tmp/.pk11ipc1` | High
13 | File | `/tmp/adb.log` | Medium
14 | File | `/usr/bin/cu` | Medium
15 | File | `/var/crash/vmcore.log` | High
16 | File | `aclient.exe` | Medium
17 | File | `addadmin.asp` | Medium
18 | File | `admin` | Low
19 | File | `admin.php` | Medium
20 | File | `admin.rssreader.php` | High
21 | File | `admin/configuration/modifier.php` | High
22 | File | `admin/skins.php` | High
23 | File | `adminconsole` | Medium
24 | File | `administrator/mail/download.cfm` | High
25 | File | `admin_board.php` | High
26 | File | `af_netlink.c` | Medium
27 | File | `ajax.php` | Medium
28 | File | `ajaxRequest/methodCall.do` | High
29 | File | `announcements.php` | High
30 | File | `apache2/modsecurity.c` | High
31 | File | `apply.cgi` | Medium
32 | File | `app_new.php` | Medium
33 | File | `aspx` | Low
34 | File | `AttachmentsList.aspx` | High
35 | File | `Atx45.ocx` | Medium
36 | File | `auction_details.php` | High
37 | File | `auth.php` | Medium
38 | File | `aut_verifica.inc.php` | High
39 | File | `awsguest.php` | Medium
40 | File | `b2edit.showposts.php` | High
41 | File | `backend.php/screen.php/comment.php` | High
42 | File | `basicfunctions.php` | High
43 | File | `board.cgi` | Medium
44 | File | `bug_actiongroup_ext_page.php` | High
45 | File | `canned_opr.php` | High
46 | File | `cart.cgi` | Medium
47 | File | `cat.asp` | Low
48 | File | `cddbcontrolaol.cddbaolcontrol` | High
49 | File | `channel.asp` | Medium
50 | File | `class_auth.php` | High
51 | File | `compte.php` | Medium
52 | ... | ... | ...

There are 448 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2021/06/threat-roundup-0604-0611.html
* https://blog.talosintelligence.com/2021/08/threat-roundup-0820-0827.html
* https://blog.talosintelligence.com/2021/09/threat-roundup-0827-0903.html
* https://blog.talosintelligence.com/2022/01/threat-roundup-0121-0128.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
