# ChaChi - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [ChaChi](https://vuldb.com/?actor.chachi). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.chachi](https://vuldb.com/?actor.chachi)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with ChaChi:

* [US](https://vuldb.com/?country.us)
* [FR](https://vuldb.com/?country.fr)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 17 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of ChaChi.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [23.83.133.136](https://vuldb.com/?ip.23.83.133.136) | - | - | High
2 | [37.120.140.184](https://vuldb.com/?ip.37.120.140.184) | - | - | High
3 | [37.120.140.247](https://vuldb.com/?ip.37.120.140.247) | - | - | High
4 | [37.120.145.208](https://vuldb.com/?ip.37.120.145.208) | amirah.thatisthebest.club | - | High
5 | [37.221.113.66](https://vuldb.com/?ip.37.221.113.66) | - | - | High
6 | [45.147.228.49](https://vuldb.com/?ip.45.147.228.49) | - | - | High
7 | ... | ... | ... | ...

There are 26 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _ChaChi_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 6 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by ChaChi. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/.env` | Low
3 | File | `//etc/RT2870STA.dat` | High
4 | File | `/cgi-bin/activate.cgi` | High
5 | File | `/cgi-bin/koha/acqui/supplier.pl?op=enter` | High
6 | File | `/cgi-bin/nobody` | High
7 | File | `/cgi-bin/nobody/Search.cgi` | High
8 | File | `/export` | Low
9 | File | `/forum/away.php` | High
10 | File | `/get_getnetworkconf.cgi` | High
11 | File | `/horde/util/go.php` | High
12 | File | `/nova/bin/detnet` | High
13 | File | `/opensis/modules/users/Staff.php` | High
14 | File | `/plugins/servlet/gadgets/makeRequest` | High
15 | File | `/req_password_user.php` | High
16 | File | `/show_news.php` | High
17 | File | `/tmp` | Low
18 | File | `/uncpath/` | Medium
19 | File | `/Uploads` | Medium
20 | File | `/userRpm/MediaServerFoldersCfgRpm.htm` | High
21 | File | `/WEB-INF/web.xml` | High
22 | File | `/webconsole/APIController` | High
23 | File | `AccountStatus.jsp` | High
24 | File | `add.php` | Low
25 | File | `addentry.php` | Medium
26 | File | `admin.htm` | Medium
27 | File | `admin.php` | Medium
28 | File | `admin/article_category.php?rec=update` | High
29 | ... | ... | ...

There are 246 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blogs.blackberry.com/en/2021/06/pysa-loves-chachi-a-new-golang-rat

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
