# CoinStomp - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [CoinStomp](https://vuldb.com/?actor.coinstomp). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.coinstomp](https://vuldb.com/?actor.coinstomp)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with CoinStomp:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 1 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of CoinStomp.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [106.53.115.114](https://vuldb.com/?ip.106.53.115.114) | - | - | High
2 | [109.234.36.173](https://vuldb.com/?ip.109.234.36.173) | host-109-234-36-173.hosted-by-vdsina.ru | - | High
3 | [205.185.113.151](https://vuldb.com/?ip.205.185.113.151) | - | - | High

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _CoinStomp_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 5 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by CoinStomp. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/category_view.php` | High
2 | File | `/frontend/x3/cpanelpro/filelist-thumbs.html` | High
3 | File | `/fs/cifs/file.c` | High
4 | File | `/highlight/index.html` | High
5 | File | `/hotel.php` | Medium
6 | File | `/Login.do` | Medium
7 | File | `/var/etc/shadow` | High
8 | File | `/var/log/cgred` | High
9 | File | `/var/run/hostapd` | High
10 | File | `add.php` | Low
11 | File | `AddEvent.php` | Medium
12 | File | `addlisting.asp` | High
13 | File | `add_tmsp.php` | Medium
14 | File | `admin.php` | Medium
15 | File | `admin/handlers.php` | High
16 | File | `admin/help.php` | High
17 | File | `admin/modules/system/app_user.php` | High
18 | File | `admin/tools/trackback/index.php` | High
19 | File | `admin/users_edit.php` | High
20 | File | `administrators/backups/` | High
21 | File | `afmparse.c` | Medium
22 | File | `ajax.php` | Medium
23 | File | `answers.php` | Medium
24 | File | `apsetup.php` | Medium
25 | File | `arch/powerpc/kernel/process.c` | High
26 | File | `arch/x86/kvm/vmx.c` | High
27 | File | `ArchiveUtil.java` | High
28 | File | `bmp.c` | Low
29 | File | `browse.php` | Medium
30 | File | `buy.php` | Low
31 | File | `calendar.class.php` | High
32 | File | `calendar/submit/` | High
33 | File | `category.php` | Medium
34 | File | `cc_guestbook.pl` | High
35 | File | `centipaid_class.php` | High
36 | File | `channel.c` | Medium
37 | File | `chetcpasswd.cgi` | High
38 | File | `clastree.htm` | Medium
39 | File | `client-assist.php` | High
40 | File | `coders/dds.c` | Medium
41 | File | `coders/webp.c` | High
42 | File | `CollabNetApp.java` | High
43 | File | `collection.class.php` | High
44 | ... | ... | ...

There are 384 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://www.cadosecurity.com/coinstomp-malware-family-targets-asian-cloud-service-providers/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
