# Dust Storm - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Dust Storm](https://vuldb.com/?actor.dust_storm). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.dust_storm](https://vuldb.com/?actor.dust_storm)

## Campaigns

The following _campaigns_ are known and can be associated with Dust Storm:

* Dust Storm

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Dust Storm:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)
* [GB](https://vuldb.com/?country.gb)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Dust Storm.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [6.9.2.1](https://vuldb.com/?ip.6.9.2.1) | - | Dust Storm | High
2 | [23.238.229.128](https://vuldb.com/?ip.23.238.229.128) | - | Dust Storm | High
3 | [27.255.72.68](https://vuldb.com/?ip.27.255.72.68) | - | Dust Storm | High
4 | [27.255.72.69](https://vuldb.com/?ip.27.255.72.69) | - | Dust Storm | High
5 | [27.255.72.78](https://vuldb.com/?ip.27.255.72.78) | - | Dust Storm | High
6 | [59.120.59.2](https://vuldb.com/?ip.59.120.59.2) | 59-120-59-2.hinet-ip.hinet.net | Dust Storm | High
7 | [59.188.13.133](https://vuldb.com/?ip.59.188.13.133) | - | Dust Storm | High
8 | ... | ... | ... | ...

There are 27 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Dust Storm_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-307, CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 7 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Dust Storm. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `%PROGRAMDATA%\checkmk\agent\local` | High
2 | File | `.htaccess` | Medium
3 | File | `/#/CampaignManager/users` | High
4 | File | `//` | Low
5 | File | `/admin.php?action=themeinstall` | High
6 | File | `/admin/?setting-base.htm` | High
7 | File | `/admin/admin_login.php` | High
8 | File | `/admin/login.php` | High
9 | File | `/apply_noauth.cgi` | High
10 | File | `/audit/log/log_management.php` | High
11 | File | `/bin/login` | Medium
12 | File | `/bin/sh` | Low
13 | File | `/cgi-bin/login` | High
14 | File | `/classes/profile.class.php` | High
15 | File | `/dev/tty` | Medium
16 | File | `/doorgets/app/requests/user/modulecategoryRequest.php` | High
17 | File | `/downloads/` | Medium
18 | File | `/IISADMPWD` | Medium
19 | File | `/inc/session.php` | High
20 | File | `/index.php` | Medium
21 | File | `/login` | Low
22 | File | `/login.html` | Medium
23 | File | `/magnoliaPublic/travel/members/login.html` | High
24 | File | `/member/index/login.html` | High
25 | File | `/modules/certinfo/index.php` | High
26 | File | `/restful-services/publish` | High
27 | File | `/ScadaBR/login.htm` | High
28 | File | `/secure/admin/InsightDefaultCustomFieldConfig.jspa` | High
29 | File | `/system/tool/ping.php` | High
30 | File | `/upload` | Low
31 | File | `/usr/bin/pkexec` | High
32 | File | `/var/adm/btmp` | High
33 | File | `?location=search` | High
34 | File | `account/login.php` | High
35 | File | `add.asp` | Low
36 | File | `add.php` | Low
37 | File | `admin.inc.php` | High
38 | File | `admin.php` | Medium
39 | File | `admin.php?m=backup&c=backup&a=doback` | High
40 | File | `admin/conf_users_edit.php` | High
41 | File | `admin/index.php` | High
42 | File | `admin/login.asp` | High
43 | File | `admin/login.php` | High
44 | File | `admin/nos/login` | High
45 | File | `admin\db\DoSql.php` | High
46 | ... | ... | ...

There are 396 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://www.threatminer.org/report.php?q=Op_Dust_Storm_Report.pdf&y=2016

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
