# Gamarue - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Gamarue](https://vuldb.com/?actor.gamarue). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.gamarue](https://vuldb.com/?actor.gamarue)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Gamarue:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [ES](https://vuldb.com/?country.es)
* ...

There are 11 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Gamarue.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.154.191.57](https://vuldb.com/?ip.5.154.191.57) | - | - | High
2 | [20.186.50.83](https://vuldb.com/?ip.20.186.50.83) | - | - | High
3 | [37.187.0.40](https://vuldb.com/?ip.37.187.0.40) | ns3108067.ip-37-187-0.eu | - | High
4 | [40.81.11.194](https://vuldb.com/?ip.40.81.11.194) | - | - | High
5 | [40.91.94.203](https://vuldb.com/?ip.40.91.94.203) | - | - | High
6 | [45.8.124.25](https://vuldb.com/?ip.45.8.124.25) | free.gbnhost.com | - | High
7 | [45.122.138.6](https://vuldb.com/?ip.45.122.138.6) | - | - | High
8 | [45.128.204.36](https://vuldb.com/?ip.45.128.204.36) | - | - | High
9 | [45.128.207.237](https://vuldb.com/?ip.45.128.207.237) | - | - | High
10 | [46.45.169.106](https://vuldb.com/?ip.46.45.169.106) | 46-45-169-106.turkrdns.com | - | High
11 | [46.249.38.155](https://vuldb.com/?ip.46.249.38.155) | - | - | High
12 | [46.254.21.69](https://vuldb.com/?ip.46.254.21.69) | h13.ihc.ru | - | High
13 | [50.116.23.211](https://vuldb.com/?ip.50.116.23.211) | www.eqnic.net | - | High
14 | ... | ... | ... | ...

There are 51 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Gamarue_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-307, CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 7 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Gamarue. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `%PROGRAMDATA%\OpenVPN Connect\drivers\tap\amd64\win10` | High
2 | File | `%PROGRAMDATA%\Razer\Synapse3\Service\bin` | High
3 | File | `.authlie` | Medium
4 | File | `.htaccess` | Medium
5 | File | `/+CSCOE+/logon.html` | High
6 | File | `/admin/settings/sites/new` | High
7 | File | `/admin_giant/` | High
8 | File | `/advanced/adv_dns.xgi` | High
9 | File | `/folder/list` | Medium
10 | File | `/forms/nslookupHandler` | High
11 | File | `/getcfg.php` | Medium
12 | File | `/goform/GetNewDir` | High
13 | File | `/goform/right_now_d` | High
14 | File | `/gracemedia-media-player/templates/files/ajax_controller.php` | High
15 | File | `/group/comment` | High
16 | File | `/home/home_parent.xgi` | High
17 | File | `/lookin/info` | Medium
18 | File | `/plugins/servlet/jira-blockers/` | High
19 | File | `/status/status_log.sys` | High
20 | File | `/themes/<php_file_name>` | High
21 | File | `/tmp` | Low
22 | File | `/uncpath/` | Medium
23 | File | `/upload` | Low
24 | File | `/usr/bin/shutter` | High
25 | File | `/zm/index.php` | High
26 | File | `adclick.php` | Medium
27 | File | `admin-ajax.php` | High
28 | File | `admin.php` | Medium
29 | File | `admin/?n=tags&c=index&a=doSaveTags` | High
30 | File | `admin/controller/pages/localisation/language.php` | High
31 | File | `admin/fm/` | Medium
32 | File | `admin/pages/*/edit` | High
33 | File | `admincp/attachment.php&do=rebuild&type` | High
34 | File | `administrator/index.php?option=com_pago&view=comments` | High
35 | File | `ajax.php` | Medium
36 | File | `ajax_mod_security.php` | High
37 | File | `api.php` | Low
38 | File | `appconfig.php` | High
39 | ... | ... | ...

There are 339 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2018/09/threat-roundup-0907-0914.html
* https://blog.talosintelligence.com/2019/06/threat-roundup-0621-0628.html
* https://blog.talosintelligence.com/2019/07/threat-roundup-0628-0705.html
* https://blog.talosintelligence.com/2021/02/threat-roundup-0212-0219.html
* https://blog.talosintelligence.com/2021/04/threat-roundup-0326-0402.html
* https://blog.talosintelligence.com/2021/09/threat-roundup-0827-0903.html
* https://blog.talosintelligence.com/2022/01/threat-roundup-0121-0128.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
