# Lotus Blossom - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Lotus Blossom](https://vuldb.com/?actor.lotus_blossom). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.lotus_blossom](https://vuldb.com/?actor.lotus_blossom)

## Campaigns

The following _campaigns_ are known and can be associated with Lotus Blossom:

* Emissary

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Lotus Blossom:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [ES](https://vuldb.com/?country.es)
* ...

There are 8 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Lotus Blossom.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [23.234.63.197](https://vuldb.com/?ip.23.234.63.197) | - | - | High
2 | [27.255.64.231](https://vuldb.com/?ip.27.255.64.231) | - | - | High
3 | [45.64.113.130](https://vuldb.com/?ip.45.64.113.130) | - | - | High
4 | [46.251.237.59](https://vuldb.com/?ip.46.251.237.59) | - | - | High
5 | [50.7.11.10](https://vuldb.com/?ip.50.7.11.10) | yem1.entregadorvirtual9.com | - | High
6 | [58.64.183.92](https://vuldb.com/?ip.58.64.183.92) | - | - | High
7 | [59.6.2.16](https://vuldb.com/?ip.59.6.2.16) | - | - | High
8 | [59.188.247.32](https://vuldb.com/?ip.59.188.247.32) | - | - | High
9 | [61.58.31.102](https://vuldb.com/?ip.61.58.31.102) | - | - | High
10 | [95.154.195.152](https://vuldb.com/?ip.95.154.195.152) | hrms.blinkgator.net | - | High
11 | ... | ... | ... | ...

There are 39 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Lotus Blossom_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 3 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Lotus Blossom. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/cgi-bin/wapopen` | High
3 | File | `/etc/ajenti/config.yml` | High
4 | File | `/goform/telnet` | High
5 | File | `/modules/profile/index.php` | High
6 | File | `/php/init.poll.php` | High
7 | File | `/rom-0` | Low
8 | File | `/tmp/phpglibccheck` | High
9 | File | `/uncpath/` | Medium
10 | File | `/var/tmp/sess_*` | High
11 | File | `/vmi/manager/engine/management/commands/apns_worker.py` | High
12 | File | `action.php` | Medium
13 | File | `actionphp/download.File.php` | High
14 | File | `add_comment.php` | High
15 | File | `admin/admin.php` | High
16 | File | `admin/content.php` | High
17 | File | `admin/index.php?id=users/action=edit/user_id=1` | High
18 | File | `admin/memberviewdetails.php` | High
19 | File | `admin/src/containers/InputModalStepperProvider/index.js` | High
20 | File | `affich.php` | Medium
21 | File | `agent/Core/Controller/SendRequest.cpp` | High
22 | File | `akeyActivationLogin.do` | High
23 | File | `album_portal.php` | High
24 | File | `apache-auth.conf` | High
25 | File | `askapache-firefox-adsense.php` | High
26 | File | `attachment.cgi` | High
27 | File | `basic_search_result.php` | High
28 | File | `blueprints/sections/edit/1` | High
29 | File | `books.php` | Medium
30 | File | `cart_add.php` | Medium
31 | File | `CFS.c` | Low
32 | File | `cgi-bin/gnudip.cgi` | High
33 | File | `checktransferstatus.php` | High
34 | File | `checkuser.php` | High
35 | File | `class.SystemAction.php` | High
36 | File | `clientarea.php` | High
37 | File | `cmdmon.c` | Medium
38 | File | `collectivite.class.php` | High
39 | File | `confirm.php` | Medium
40 | File | `contact` | Low
41 | File | `control.c` | Medium
42 | File | `core-util.c` | Medium
43 | File | `core/coreuserinputhandler.cpp` | High
44 | File | `d1_both.c` | Medium
45 | File | `data/gbconfiguration.dat` | High
46 | File | `Debug_command_page.asp` | High
47 | File | `details_view.php` | High
48 | File | `Diagnose.exe` | Medium
49 | File | `DigiDocSAXParser.c` | High
50 | File | `download-file.php` | High
51 | ... | ... | ...

There are 440 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://securelist.com/the-spring-dragon-apt/70726/
* https://unit42.paloaltonetworks.com/attack-on-french-diplomat-linked-to-operation-lotus-blossom/
* https://unit42.paloaltonetworks.com/emissary-trojan-changelog-did-operation-lotus-blossom-cause-it-to-evolve/
* https://www.paloaltonetworks.com/resources/research/unit42-operation-lotus-blossom.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
