# Matryosh - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Matryosh](https://vuldb.com/?actor.matryosh). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.matryosh](https://vuldb.com/?actor.matryosh)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Matryosh:

* [US](https://vuldb.com/?country.us)
* [CA](https://vuldb.com/?country.ca)
* [ES](https://vuldb.com/?country.es)
* ...

There are 4 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Matryosh.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [46.105.34.51](https://vuldb.com/?ip.46.105.34.51) | network.g33k.host | - | High
2 | [51.83.186.134](https://vuldb.com/?ip.51.83.186.134) | vps-c9f4e53f.vps.ovh.net | - | High
3 | [51.195.91.193](https://vuldb.com/?ip.51.195.91.193) | vps-bda5972a.vps.ovh.net | - | High
4 | ... | ... | ... | ...

There are 8 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Matryosh_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 7 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Matryosh. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/.kedpm/history` | High
2 | File | `/cgi-bin/` | Medium
3 | File | `/cgi-bin/ExportAllSettings.sh` | High
4 | File | `/domain/add` | Medium
5 | File | `/download` | Medium
6 | File | `/exponent_constants.php` | High
7 | File | `/goform/` | Medium
8 | File | `/lists/admin/` | High
9 | File | `/sitecore/client/Applications/List Manager/Taskpages/Contact list` | High
10 | File | `/status.js` | Medium
11 | File | `/usr/bin/lua` | Medium
12 | File | `/websitebaker/admin/preferences/save.php` | High
13 | File | `aai.c` | Low
14 | File | `account/login.php` | High
15 | File | `admin-ajax.php` | High
16 | File | `admin.comms.php` | High
17 | File | `admin.php` | Medium
18 | File | `admin/auto.def` | High
19 | File | `admin/blog/add/` | High
20 | File | `admin/home#/person/` | High
21 | File | `admin/mcart_xls_import.php` | High
22 | File | `admin/plugin/file_manager/browse/` | High
23 | File | `admin/services/packages/remove` | High
24 | File | `admin/settings/update/` | High
25 | File | `administrator/components/com_media/helpers/media.php` | High
26 | File | `adm_config_report.php` | High
27 | File | `adm_program/modules/members/members_function.php` | High
28 | File | `album_portal.php` | High
29 | File | `amf.c` | Low
30 | File | `api.c` | Low
31 | File | `api/includes/systems.php` | High
32 | File | `archive_read_support_format_cab.c` | High
33 | File | `assembler/MacroAssemblerARM64.h` | High
34 | File | `Autopilot/route_mgr.cxx` | High
35 | File | `avs.c` | Low
36 | File | `bank/callback1.php` | High
37 | File | `base/gdevp14.c` | High
38 | File | `base/PdfParser.cpp` | High
39 | File | `base/PdfXRefStreamParserObject.cpp:224` | High
40 | File | `bfd/aoutx.h` | Medium
41 | ... | ... | ...

There are 351 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.netlab.360.com/matryosh-botnet-is-spreading-en/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
