# Mylobot - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Mylobot](https://vuldb.com/?actor.mylobot). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.mylobot](https://vuldb.com/?actor.mylobot)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Mylobot:

* [US](https://vuldb.com/?country.us)
* [NL](https://vuldb.com/?country.nl)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 28 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Mylobot.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [46.166.173.180](https://vuldb.com/?ip.46.166.173.180) | - | - | High
2 | [70.36.107.38](https://vuldb.com/?ip.70.36.107.38) | - | - | High
3 | [70.36.107.39](https://vuldb.com/?ip.70.36.107.39) | - | - | High
4 | [74.222.19.63](https://vuldb.com/?ip.74.222.19.63) | - | - | High
5 | ... | ... | ... | ...

There are 18 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Mylobot_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-307, CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 6 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Mylobot. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.procmailrc` | Medium
2 | File | `/../conf/config.properties` | High
3 | File | `/addnews.html` | High
4 | File | `/admin/` | Low
5 | File | `/api/2.0/rest/aggregator/xml` | High
6 | File | `/api/blade-log/api/list` | High
7 | File | `/cgi-bin/webviewer_login_page` | High
8 | File | `/Config/SaveUploadedHotspotLogoFile` | High
9 | File | `/core/vendor/meenie/javascript-packer/example-inline.php` | High
10 | File | `/etc/config/rpcd` | High
11 | File | `/exponent_constants.php` | High
12 | File | `/forum/away.php` | High
13 | File | `/goform/formLogin` | High
14 | File | `/hub/api/user` | High
15 | File | `/mfaslmf/nolicense` | High
16 | File | `/opt/bin/cli` | Medium
17 | File | `/plain` | Low
18 | File | `/proc` | Low
19 | File | `/proc/ioports` | High
20 | File | `/products/details.asp` | High
21 | File | `/public/plugins/` | High
22 | File | `/RestAPI` | Medium
23 | File | `/tmp` | Low
24 | File | `/uncpath/` | Medium
25 | File | `/User/saveUser` | High
26 | File | `/ViewUserHover.jspa` | High
27 | File | `/WEB-INF/web.xml` | High
28 | File | `/wp-admin/admin-ajax.php` | High
29 | File | `/wp-json/wc/v3/webhooks` | High
30 | File | `14all.cgi/14all-1.1.cgi/traffic.cgi/mrtg.cgi` | High
31 | File | `abc-pcie.c` | Medium
32 | File | `accountmanagement.php` | High
33 | File | `addentry.php` | Medium
34 | File | `adherents/subscription/info.php` | High
35 | File | `admin.joomlaflashfun.php` | High
36 | File | `admin.joomlaradiov5.php` | High
37 | File | `admin.panoramic.php` | High
38 | File | `admin.php` | Medium
39 | File | `admin/change-password.php` | High
40 | File | `admin/index.php` | High
41 | File | `admin/killsource` | High
42 | File | `admin/scripts/FileUploader/php.php` | High
43 | ... | ... | ...

There are 367 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://ioc.hatenablog.com/entry/2018/11/14/000000

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
