# Nymaim - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Nymaim](https://vuldb.com/?actor.nymaim). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.nymaim](https://vuldb.com/?actor.nymaim)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Nymaim:

* [US](https://vuldb.com/?country.us)
* [SI](https://vuldb.com/?country.si)
* [BG](https://vuldb.com/?country.bg)
* ...

There are 7 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Nymaim.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [37.152.176.90](https://vuldb.com/?ip.37.152.176.90) | - | - | High
2 | [46.47.98.128](https://vuldb.com/?ip.46.47.98.128) | 46-47-98-128.stz.ddns.bulsat.com | - | High
3 | [46.238.18.157](https://vuldb.com/?ip.46.238.18.157) | ip-46-238-18-157.home.megalan.bg | - | High
4 | [47.91.242.212](https://vuldb.com/?ip.47.91.242.212) | - | - | High
5 | [51.218.181.145](https://vuldb.com/?ip.51.218.181.145) | - | - | High
6 | [52.85.144.32](https://vuldb.com/?ip.52.85.144.32) | server-52-85-144-32.iad89.r.cloudfront.net | - | High
7 | ... | ... | ... | ...

There are 22 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Nymaim_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-274, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-307, CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 7 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Nymaim. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `//` | Low
2 | File | `/adfs/ls` | Medium
3 | File | `/admin/doctors/view_doctor.php` | High
4 | File | `/appliance/users?action=edit` | High
5 | File | `/config/getuser` | High
6 | File | `/data-service/users/` | High
7 | File | `/IISADMPWD` | Medium
8 | File | `/js/app.js` | Medium
9 | File | `/login` | Low
10 | File | `/monitor/s_headmodel.php` | High
11 | File | `/pro/repo-create.html` | High
12 | File | `/public/plugins/` | High
13 | File | `/rest/api/1.0/issues/{id}/ActionsAndOperations` | High
14 | File | `/rest/api/latest/projectvalidate/key` | High
15 | File | `/rest/collectors/1.0/template/custom` | High
16 | File | `/SAP_Information_System/controllers/add_admin.php` | High
17 | File | `/secure/admin/InsightDefaultCustomFieldConfig.jspa` | High
18 | File | `/server-info` | Medium
19 | File | `/services` | Medium
20 | File | `/test/cookie/` | High
21 | File | `/uncpath/` | Medium
22 | File | `/usr/bin/at` | Medium
23 | File | `/usr/bin/pkexec` | High
24 | File | `/WEB-INF/web.xml` | High
25 | File | `admin-ajax.php` | High
26 | ... | ... | ...

There are 217 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2021/06/threat-roundup-0528-0604.html
* https://blog.talosintelligence.com/2021/07/threat-roundup-0625-0702.html
* https://blog.talosintelligence.com/2021/08/threat-roundup-0730-0806.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
