# Redline - Cyber Threat Intelligence

The indicators are related to [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Redline](https://vuldb.com/?actor.redline). The activity monitoring correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, activities, intentions, emerging research, and attacks. Our unique predictive model is able to forecast activities and their characteristics.

Live data and more analysis capabilities are available at [https://vuldb.com/?actor.redline](https://vuldb.com/?actor.redline)

## Countries

These countries are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Redline:

* US
* RU
* TR
* ...

There are 10 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These indicators of compromise indicate associated network ressources which are known to be part of research and attack activities of Redline.

ID | IP address | Hostname | Confidence
-- | ---------- | -------- | ----------
1 | 8.249.227.254 | - | High
2 | 8.249.241.254 | - | High
3 | 8.253.45.248 | - | High
4 | 8.253.132.120 | - | High
5 | 13.52.79.131 | ec2-13-52-79-131.us-west-1.compute.amazonaws.com | Medium
6 | 23.21.205.229 | ec2-23-21-205-229.compute-1.amazonaws.com | Medium
7 | 23.21.224.49 | ec2-23-21-224-49.compute-1.amazonaws.com | Medium
8 | 23.23.104.250 | ec2-23-23-104-250.compute-1.amazonaws.com | Medium
9 | 23.46.238.194 | a23-46-238-194.deploy.static.akamaitechnologies.com | High
10 | 34.76.8.115 | 115.8.76.34.bc.googleusercontent.com | Medium
11 | 37.46.150.90 | - | High
12 | 45.33.89.196 | li1035-196.members.linode.com | High
13 | 45.67.231.50 | licher.lone.example.com | High
14 | 45.84.0.108 | pangeransosmed.vip | High
15 | 45.84.0.200 | 1c.capricorn.md | High
16 | ... | ... | ...

There are 62 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

Tactics, techniques, and procedures summarize the suspected ATT&CK techniques used by Redline. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Description | Confidence
-- | --------- | ----------- | ----------
1 | T1059.007 | Cross Site Scripting | High
2 | T1068 | Execution with Unnecessary Privileges | High
3 | T1110.001 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ...

There are 9 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These indicators of attack list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Redline. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/config.php?display=disa&view=form` | High
2 | File | `/admin/edit_review.php` | High
3 | File | `/adminlogin.asp` | High
4 | File | `/api/blade-log/api/list` | High
5 | File | `/api/v2/labels/` | High
6 | File | `/cgi-bin/supervisor/PwdGrp.cgi` | High
7 | File | `/Config/SaveUploadedHotspotLogoFile` | High
8 | File | `/dev/shm` | Medium
9 | File | `/dl/dl_print.php` | High
10 | File | `/getcfg.php` | Medium
11 | File | `/goform/RgUrlBlock.asp` | High
12 | File | `/index.php` | Medium
13 | File | `/info.asp` | Medium
14 | File | `/info.xml` | Medium
15 | File | `/jeecg-boot/sys/common/upload` | High
16 | File | `/mc-admin/post.php?state=delete&delete` | High
17 | File | `/product_list.php` | High
18 | File | `/see_more_details.php` | High
19 | File | `/ucms/chk.php` | High
20 | File | `5.2.9\syscrb.exe` | High
21 | File | `abc-pcie.c` | Medium
22 | File | `adclick.php` | Medium
23 | File | `addentry.php` | Medium
24 | File | `addmember.php` | High
25 | File | `addtocart.asp` | High
26 | File | `addtomylist.asp` | High
27 | File | `admin.php/admin/configset/index/group/upload.html` | High
28 | File | `admin.x-shop.php` | High
29 | File | `admin/auth.php` | High
30 | File | `admin/category.inc.php` | High
31 | File | `admin/config/confmgr.php` | High
32 | File | `admin/import/class-import-settings.php` | High
33 | File | `admin/user/group/update` | High
34 | File | `admincp/auth/checklogin.php` | High
35 | ... | ... | ...

There are 295 more IOA items available. Please use our online service to access the data.

## References

The following list contains external sources which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2021/02/threat-roundup-0212-0219.html
* https://blog.talosintelligence.com/2021/06/threat-roundup-0528-0604.html
* https://blog.talosintelligence.com/2021/06/threat-roundup-0604-0611.html
* https://blog.talosintelligence.com/2021/06/threat-roundup-0617-0624.html
* https://blog.talosintelligence.com/2021/07/threat-roundup-0625-0702.html

## Literature

The following articles explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
