# Rig Exploit Kit - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Rig Exploit Kit](https://vuldb.com/?actor.rig_exploit_kit). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.rig_exploit_kit](https://vuldb.com/?actor.rig_exploit_kit)

## Campaigns

The following _campaigns_ are known and can be associated with Rig Exploit Kit:

* Slots

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Rig Exploit Kit:

* [RU](https://vuldb.com/?country.ru)
* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 7 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Rig Exploit Kit.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.23.55.246](https://vuldb.com/?ip.5.23.55.246) | vds-cp32503.timeweb.ru | - | High
2 | [5.200.55.214](https://vuldb.com/?ip.5.200.55.214) | - | - | High
3 | [31.184.234.0](https://vuldb.com/?ip.31.184.234.0) | - | - | High
4 | [37.46.135.254](https://vuldb.com/?ip.37.46.135.254) | info115.fvds.ru | - | High
5 | [37.187.221.148](https://vuldb.com/?ip.37.187.221.148) | ip148.ip-37-187-221.eu | - | High
6 | [37.230.117.43](https://vuldb.com/?ip.37.230.117.43) | ebe5f2eee2.fvds.ru | - | High
7 | [37.230.117.77](https://vuldb.com/?ip.37.230.117.77) | - | - | High
8 | [37.230.117.87](https://vuldb.com/?ip.37.230.117.87) | vk-one.ru | - | High
9 | [37.230.117.169](https://vuldb.com/?ip.37.230.117.169) | ivmarh.fvds.ru | - | High
10 | [45.63.115.214](https://vuldb.com/?ip.45.63.115.214) | 45.63.115.214.vultrusercontent.com | - | High
11 | [46.30.42.0](https://vuldb.com/?ip.46.30.42.0) | subnet.eurobyte.ru.42.30.46.in-addr.arpa | - | High
12 | [46.30.43.0](https://vuldb.com/?ip.46.30.43.0) | subnet.eurobyte.ru.43.30.46.in-addr.arpa | - | High
13 | [46.30.44.0](https://vuldb.com/?ip.46.30.44.0) | subnet.eurobyte.ru.44.30.46.in-addr.arpa | - | High
14 | [46.30.45.0](https://vuldb.com/?ip.46.30.45.0) | subnet.eurobyte.ru.45.30.46.in-addr.arpa | - | High
15 | [46.30.46.0](https://vuldb.com/?ip.46.30.46.0) | subnet.eurobyte.ru.46.30.46.in-addr.arpa | - | High
16 | ... | ... | ... | ...

There are 62 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Rig Exploit Kit_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 4 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Rig Exploit Kit. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/app/Http/Controllers/Admin/NEditorController.php` | High
3 | File | `/apply.cgi` | Medium
4 | File | `/forum/away.php` | High
5 | File | `/mifs/c/i/reg/reg.html` | High
6 | File | `/objects/getImageMP4.php` | High
7 | File | `/payu/icpcheckout/` | High
8 | File | `/proc/kcore/` | Medium
9 | File | `/uncpath/` | Medium
10 | File | `/xAdmin/html/cm_doclist_view_uc.jsp` | High
11 | File | `adclick.php` | Medium
12 | File | `add_comment.php` | High
13 | File | `admin.jcomments.php` | High
14 | File | `admin.php` | Medium
15 | File | `admin/index.php` | High
16 | File | `AppCompatCache.exe` | High
17 | File | `asn1fix_retrieve.c` | High
18 | File | `bigsam_guestbook.php` | High
19 | File | `books.php` | Medium
20 | File | `card/pay/.../amount` | High
21 | File | `category.cfm` | Medium
22 | ... | ... | ...

There are 186 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2016/01/rigging-compromise.html
* https://blog.talosintelligence.com/2019/07/malvertising-deepdive.html
* https://isc.sans.edu/forums/diary/1+compromised+site+2+campaigns/21381/
* https://isc.sans.edu/forums/diary/An+infection+from+Rig+exploit+kit/25040/
* https://isc.sans.edu/forums/diary/CryptoShield+Ransomware+from+Rig+EK/22047/
* https://isc.sans.edu/forums/diary/pseudoDarkleech+Rig+EK/21595/
* https://isc.sans.edu/forums/diary/Rig+Exploit+Kit+sends+PitouB+Trojan/25068/
* https://isc.sans.edu/forums/diary/Seamless+Campaign+using+Rig+Exploit+Kit+to+send+Ramnit+Trojan/22404/
* https://isc.sans.edu/forums/diary/Throwback+Friday+An+Example+of+Rig+Exploit+Kit/26990/
* https://research.checkpoint.com/2018/new-rig-exploit-kit-campaign-dropping-xmrig-miner/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
