# Roaming Mantis - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Roaming Mantis](https://vuldb.com/?actor.roaming_mantis). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.roaming_mantis](https://vuldb.com/?actor.roaming_mantis)

## Campaigns

The following _campaigns_ are known and can be associated with Roaming Mantis:

* Asia Mobile Devices

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Roaming Mantis:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)
* [DE](https://vuldb.com/?country.de)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Roaming Mantis.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [43.240.14.44](https://vuldb.com/?ip.43.240.14.44) | scdc.worra.com | Asia Mobile Devices | High
2 | [118.168.201.70](https://vuldb.com/?ip.118.168.201.70) | 118-168-201-70.dynamic-ip.hinet.net | Asia Mobile Devices | High
3 | [118.168.202.125](https://vuldb.com/?ip.118.168.202.125) | 118-168-202-125.dynamic-ip.hinet.net | Asia Mobile Devices | High
4 | ... | ... | ... | ...

There are 8 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Roaming Mantis_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1211 | CWE-254 | 7PK Security Features | High
4 | ... | ... | ... | ...

There are 2 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Roaming Mantis. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/addnews.html` | High
3 | File | `/admin/system/database/filedown.php` | High
4 | File | `/bin/boa` | Medium
5 | File | `/cgi-bin/upload_vpntar` | High
6 | File | `/cgi-bin/user/Config.cgi` | High
7 | File | `/MTFWU` | Low
8 | File | `/okm:root` | Medium
9 | File | `/wp-content/plugins/updraftplus/admin.php` | High
10 | File | `actions/authenticate.php` | High
11 | ... | ... | ...

There are 79 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.kaspersky.co.jp/roaming-mantis-update/20383/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
