# Russia Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Russia Unknown](https://vuldb.com/?actor.russia_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.russia_unknown](https://vuldb.com/?actor.russia_unknown)

## Campaigns

The following _campaigns_ are known and can be associated with Russia Unknown:

* CVE-2021-34527
* Ukraine Document Management System

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Russia Unknown:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [GB](https://vuldb.com/?country.gb)
* ...

There are 10 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Russia Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.23.52.131](https://vuldb.com/?ip.5.23.52.131) | 418209-ci33127.tmweb.ru | - | High
2 | [5.45.119.124](https://vuldb.com/?ip.5.45.119.124) | - | - | High
3 | [5.196.167.184](https://vuldb.com/?ip.5.196.167.184) | ip184.ip-5-196-167.eu | - | High
4 | [37.139.7.16](https://vuldb.com/?ip.37.139.7.16) | - | - | High
5 | [45.8.228.49](https://vuldb.com/?ip.45.8.228.49) | - | - | High
6 | [45.32.137.94](https://vuldb.com/?ip.45.32.137.94) | 45.32.137.94.vultrusercontent.com | CVE-2021-34527 | High
7 | ... | ... | ... | ...

There are 25 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Russia Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 4 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Russia Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/data/wps.setup.json` | High
3 | File | `/osm/REGISTER.cmd` | High
4 | File | `/product.php` | Medium
5 | File | `/Pwrchute` | Medium
6 | File | `/uncpath/` | Medium
7 | File | `/wbg/core/_includes/authorization.inc.php` | High
8 | File | `/WEB-INF/web.xml` | High
9 | File | `adm-menu.php` | Medium
10 | File | `adm-style.php` | High
11 | File | `admin/admin.shtml` | High
12 | File | `admin/controller/pages/localisation/language.php` | High
13 | File | `admin/show.php?rec=update` | High
14 | File | `admin/web_config.php` | High
15 | File | `adminpanel/modules/pro/inc/ajax.php` | High
16 | File | `admin_add.php` | High
17 | File | `ajax.php` | Medium
18 | File | `api/v1/User?filterList` | High
19 | File | `apply.cgi` | Medium
20 | File | `arch/powerpc/kernel/traps.c` | High
21 | File | `architext.conf` | High
22 | File | `attachment_send.php` | High
23 | File | `avrc_pars_tg.cc` | High
24 | File | `base/ErrorHandler.php` | High
25 | File | `bg_console/index.php?m=opt&c=request` | High
26 | File | `board.php` | Medium
27 | ... | ... | ...

There are 226 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://isc.sans.edu/forums/diary/A+few+IoCs+related+to+CVE20205902/26378/
* https://isc.sans.edu/forums/diary/More+Russian+language+malspam+pushing+Shade+Troldesh+ransomware/24668/
* https://www.cisa.gov/uscert/ncas/alerts/aa20-296a
* https://www.cisa.gov/uscert/ncas/alerts/aa22-074a
* https://www.rnbo.gov.ua/en/Diialnist/4823.html
* https://www.trellix.com/en-gb/about/newsroom/stories/threat-labs/prime-ministers-office-compromised.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
