# SideCopy - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [SideCopy](https://vuldb.com/?actor.sidecopy). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.sidecopy](https://vuldb.com/?actor.sidecopy)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with SideCopy:

* [NL](https://vuldb.com/?country.nl)
* [US](https://vuldb.com/?country.us)
* [DE](https://vuldb.com/?country.de)
* ...

There are 5 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of SideCopy.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [109.236.85.152](https://vuldb.com/?ip.109.236.85.152) | customer.worldstream.nl | - | High
2 | [144.91.65.100](https://vuldb.com/?ip.144.91.65.100) | vmi652772.contaboserver.net | - | High
3 | [144.91.87.179](https://vuldb.com/?ip.144.91.87.179) | vmi778487.contaboserver.net | - | High
4 | ... | ... | ... | ...

There are 13 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _SideCopy_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-307, CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 6 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by SideCopy. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.travis.yml` | Medium
2 | File | `/.env` | Low
3 | File | `/admin.php` | Medium
4 | File | `/dvcset/sysset/set.cgi` | High
5 | File | `/file?action=download&file` | High
6 | File | `/medical/inventories.php` | High
7 | File | `/monitoring` | Medium
8 | File | `/NAGErrors` | Medium
9 | File | `/plugins/servlet/audit/resource` | High
10 | File | `/plugins/servlet/project-config/PROJECT/roles` | High
11 | File | `/replication` | Medium
12 | File | `/RestAPI` | Medium
13 | File | `/tmp` | Low
14 | File | `/tmp/speedtest_urls.xml` | High
15 | File | `/uncpath/` | Medium
16 | File | `/var/log/nginx` | High
17 | File | `adclick.php` | Medium
18 | File | `admin-ajax.php?action=get_wdtable order[0][dir]` | High
19 | File | `admin/index.php` | High
20 | File | `admin\model\catalog\download.php` | High
21 | File | `apcupsd.pid` | Medium
22 | File | `api/sms/send-sms` | High
23 | File | `api/v1/alarms` | High
24 | File | `application/controller/InstallerController.php` | High
25 | File | `arch/powerpc/kvm/book3s_rtas.c` | High
26 | File | `arformcontroller.php` | High
27 | File | `auth-gss2.c` | Medium
28 | File | `auth-options.c` | High
29 | ... | ... | ...

There are 249 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.malwarebytes.com/threat-intelligence/2021/12/sidecopy-apt-connecting-lures-to-victims-payloads-to-infrastructure/
* https://blog.talosintelligence.com/2021/07/sidecopy.html
* https://twitter.com/ShadowChasing1/status/1491261131800780810
* https://twitter.com/ShadowChasing1/status/1499704400670986240

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
