# Suppobox - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Suppobox](https://vuldb.com/?actor.suppobox). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.suppobox](https://vuldb.com/?actor.suppobox)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Suppobox:

* [ES](https://vuldb.com/?country.es)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Suppobox.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [18.216.20.136](https://vuldb.com/?ip.18.216.20.136) | ec2-18-216-20-136.us-east-2.compute.amazonaws.com | - | Medium
2 | [23.83.35.75](https://vuldb.com/?ip.23.83.35.75) | - | - | High
3 | [23.227.38.65](https://vuldb.com/?ip.23.227.38.65) | myshopify.com | - | High
4 | [23.236.62.147](https://vuldb.com/?ip.23.236.62.147) | 147.62.236.23.bc.googleusercontent.com | - | Medium
5 | [34.102.136.180](https://vuldb.com/?ip.34.102.136.180) | 180.136.102.34.bc.googleusercontent.com | - | Medium
6 | [34.198.7.77](https://vuldb.com/?ip.34.198.7.77) | ec2-34-198-7-77.compute-1.amazonaws.com | - | Medium
7 | [34.202.122.77](https://vuldb.com/?ip.34.202.122.77) | ec2-34-202-122-77.compute-1.amazonaws.com | - | Medium
8 | [34.225.38.128](https://vuldb.com/?ip.34.225.38.128) | ec2-34-225-38-128.compute-1.amazonaws.com | - | Medium
9 | [35.169.225.248](https://vuldb.com/?ip.35.169.225.248) | ec2-35-169-225-248.compute-1.amazonaws.com | - | Medium
10 | [35.186.238.101](https://vuldb.com/?ip.35.186.238.101) | 101.238.186.35.bc.googleusercontent.com | - | Medium
11 | [35.231.184.193](https://vuldb.com/?ip.35.231.184.193) | 193.184.231.35.bc.googleusercontent.com | - | Medium
12 | [39.106.40.57](https://vuldb.com/?ip.39.106.40.57) | - | - | High
13 | [43.226.23.42](https://vuldb.com/?ip.43.226.23.42) | - | - | High
14 | [45.133.2.132](https://vuldb.com/?ip.45.133.2.132) | - | - | High
15 | [45.192.23.245](https://vuldb.com/?ip.45.192.23.245) | - | - | High
16 | [45.199.245.19](https://vuldb.com/?ip.45.199.245.19) | - | - | High
17 | [46.30.213.209](https://vuldb.com/?ip.46.30.213.209) | webcluster1.webpod4-cph3.one.com | - | High
18 | [46.166.189.98](https://vuldb.com/?ip.46.166.189.98) | urlforward.topdns.com | - | High
19 | [52.0.7.30](https://vuldb.com/?ip.52.0.7.30) | ec2-52-0-7-30.compute-1.amazonaws.com | - | Medium
20 | [54.36.56.87](https://vuldb.com/?ip.54.36.56.87) | webfw-moniker.key-systems.net | - | High
21 | [54.84.104.245](https://vuldb.com/?ip.54.84.104.245) | ec2-54-84-104-245.compute-1.amazonaws.com | - | Medium
22 | [62.233.121.5](https://vuldb.com/?ip.62.233.121.5) | forward.easyspace.com | - | High
23 | ... | ... | ... | ...

There are 86 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Suppobox_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79 | Cross Site Scripting | High

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Suppobox. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `http_auth.c` | Medium
2 | File | `multipart/form-data` | High
3 | File | `tmUnblock.cgi` | High
4 | ... | ... | ...

There are 2 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/bambenek_suppobox.ipset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
