# Syrian Electronic Army - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Syrian Electronic Army](https://vuldb.com/?actor.syrian_electronic_army). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.syrian_electronic_army](https://vuldb.com/?actor.syrian_electronic_army)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Syrian Electronic Army:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [IR](https://vuldb.com/?country.ir)
* ...

There are 10 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Syrian Electronic Army.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [31.8.47.7](https://vuldb.com/?ip.31.8.47.7) | h31-8-47-7.dyn.bashtel.ru | - | High
2 | [31.8.48.7](https://vuldb.com/?ip.31.8.48.7) | h31-8-48-7.dyn.bashtel.ru | - | High
3 | [31.9.48.1](https://vuldb.com/?ip.31.9.48.1) | - | - | High
4 | [31.9.48.7](https://vuldb.com/?ip.31.9.48.7) | - | - | High
5 | [31.9.48.11](https://vuldb.com/?ip.31.9.48.11) | - | - | High
6 | [31.9.48.84](https://vuldb.com/?ip.31.9.48.84) | - | - | High
7 | [31.9.48.119](https://vuldb.com/?ip.31.9.48.119) | - | - | High
8 | [31.9.48.141](https://vuldb.com/?ip.31.9.48.141) | - | - | High
9 | ... | ... | ... | ...

There are 31 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Syrian Electronic Army_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Syrian Electronic Army. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/.ssh/authorized_keys2` | High
2 | File | `/anony/mjpg.cgi` | High
3 | File | `/html/device-id` | High
4 | File | `/uncpath/` | Medium
5 | File | `actbar3.ocx` | Medium
6 | File | `adclick.php` | Medium
7 | File | `admin.php` | Medium
8 | File | `admin/users/add` | High
9 | File | `administrator/components/com_media/helpers/media.php` | High
10 | File | `ajax-actions.php` | High
11 | File | `ajaxRequest/methodCall.do` | High
12 | ... | ... | ...

There are 90 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://www.threatminer.org/report.php?q=KL_report_syrian_malware.pdf&y=2014

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
