# TeslaCrypt - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [TeslaCrypt](https://vuldb.com/?actor.teslacrypt). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.teslacrypt](https://vuldb.com/?actor.teslacrypt)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with TeslaCrypt:

* [US](https://vuldb.com/?country.us)
* [GB](https://vuldb.com/?country.gb)
* [GR](https://vuldb.com/?country.gr)
* ...

There are 20 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of TeslaCrypt.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [2.57.138.47](https://vuldb.com/?ip.2.57.138.47) | s27.zenbox.pl | - | High
2 | [5.79.68.109](https://vuldb.com/?ip.5.79.68.109) | - | - | High
3 | [5.79.68.110](https://vuldb.com/?ip.5.79.68.110) | - | - | High
4 | [23.63.245.19](https://vuldb.com/?ip.23.63.245.19) | a23-63-245-19.deploy.static.akamaitechnologies.com | - | High
5 | [23.63.245.50](https://vuldb.com/?ip.23.63.245.50) | a23-63-245-50.deploy.static.akamaitechnologies.com | - | High
6 | [23.196.73.160](https://vuldb.com/?ip.23.196.73.160) | a23-196-73-160.deploy.static.akamaitechnologies.com | - | High
7 | [23.199.63.11](https://vuldb.com/?ip.23.199.63.11) | a23-199-63-11.deploy.static.akamaitechnologies.com | - | High
8 | [23.199.63.83](https://vuldb.com/?ip.23.199.63.83) | a23-199-63-83.deploy.static.akamaitechnologies.com | - | High
9 | [34.117.59.81](https://vuldb.com/?ip.34.117.59.81) | 81.59.117.34.bc.googleusercontent.com | - | Medium
10 | [35.195.98.220](https://vuldb.com/?ip.35.195.98.220) | 220.98.195.35.bc.googleusercontent.com | - | Medium
11 | [35.205.61.67](https://vuldb.com/?ip.35.205.61.67) | 67.61.205.35.bc.googleusercontent.com | - | Medium
12 | [35.209.43.160](https://vuldb.com/?ip.35.209.43.160) | 160.43.209.35.bc.googleusercontent.com | - | Medium
13 | [45.33.2.79](https://vuldb.com/?ip.45.33.2.79) | li956-79.members.linode.com | - | High
14 | [45.33.18.44](https://vuldb.com/?ip.45.33.18.44) | li972-44.members.linode.com | - | High
15 | [45.33.20.235](https://vuldb.com/?ip.45.33.20.235) | li974-235.members.linode.com | - | High
16 | ... | ... | ... | ...

There are 58 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _TeslaCrypt_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 6 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by TeslaCrypt. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.procmailrc` | Medium
2 | File | `/.htpasswd` | Medium
3 | File | `/adfs/ls` | Medium
4 | File | `/admin-ajax.php?action=eps_redirect_save` | High
5 | File | `/auth` | Low
6 | File | `/cgi-bin/nasset.cgi` | High
7 | File | `/cimom` | Low
8 | File | `/dashboard/view-chair-list.php` | High
9 | File | `/downloadmaster/dm_apply.cgi?action_mode=initial&download_type=General&special_cgi=get_language` | High
10 | File | `/drivers/vhost/net.c` | High
11 | File | `/etc/hosts` | Medium
12 | File | `/forum/away.php` | High
13 | File | `/GponForm/device_Form?script/` | High
14 | File | `/GponForm/fsetup_Form` | High
15 | File | `/GponForm/usb_restore_Form?script/` | High
16 | File | `/includes/decorators/global-translations.jsp` | High
17 | File | `/index.php/weblinks-categories` | High
18 | File | `/Main_Login.asp?flag=1&productname=RT-AC88U&url=/downloadmaster/task.asp` | High
19 | File | `/principals` | Medium
20 | File | `/product_list.php` | High
21 | File | `/secure/QueryComponent!Default.jspa` | High
22 | File | `/see_more_details.php` | High
23 | File | `/server-status` | High
24 | File | `/setSystemAdmin` | High
25 | File | `/uncpath/` | Medium
26 | File | `/usr/local/WowzaStreamingEngine/bin/` | High
27 | File | `/WEB-INF/web.xml` | High
28 | File | `/web/entry/en/address/adrsSetUserWizard.cgi` | High
29 | File | `400.php` | Low
30 | File | `accessibility/AccessibilityRenderObject.cpp` | High
31 | File | `addentry.php` | Medium
32 | File | `add_comment.php` | High
33 | File | `admin.php` | Medium
34 | File | `admin/editors/text/editor-body.php` | High
35 | File | `admin/executar_login.php` | High
36 | File | `admin/mcart_xls_import.php` | High
37 | File | `admin/module/init.html` | High
38 | File | `admin/setting.php` | High
39 | File | `admin_ranks.php` | High
40 | File | `advancedsearch.php` | High
41 | File | `ajax-actions.php` | High
42 | File | `alipay/alipayapi.php` | High
43 | File | `apcupsd.exe` | Medium
44 | File | `api/device/time` | High
45 | File | `attachments/edit/$file_id` | High
46 | File | `auth.inc.php` | Medium
47 | ... | ... | ...

There are 403 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2021/03/threat-roundup-0226-0305.html
* https://blog.talosintelligence.com/2021/10/threat-roundup-1001-1008.html
* https://blog.talosintelligence.com/2021/10/threat-roundup-1008-1015.html
* https://blog.talosintelligence.com/2022/01/threat-roundup-0114-0121.html
* https://blog.talosintelligence.com/2022/01/threat-roundup-0121-0128.html
* https://blog.talosintelligence.com/2022/02/threat-roundup-0128-0204.html
* https://blog.talosintelligence.com/2022/02/threat-roundup-0218-0225.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
