# Tor2mine - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Tor2mine](https://vuldb.com/?actor.tor2mine). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.tor2mine](https://vuldb.com/?actor.tor2mine)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Tor2mine:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 1 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Tor2mine.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [107.181.160.197](https://vuldb.com/?ip.107.181.160.197) | unallocated.layer6.net | - | High
2 | [107.181.174.248](https://vuldb.com/?ip.107.181.174.248) | vds-189705.hosted-by-itldc.com | - | High
3 | [107.181.187.132](https://vuldb.com/?ip.107.181.187.132) | yourdomain.org | - | High

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Tor2mine_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 3 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Tor2mine. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `'phpshell.php` | High
2 | File | `/.xsession-errors` | High
3 | File | `/admin/general/change-lang` | High
4 | File | `/Basic_Goperation_Content.asp` | High
5 | File | `/ControlManager/cgi-bin/VA/isaNVWRequest.dll` | High
6 | File | `/secure/QueryComponent!Default.jspa` | High
7 | File | `/tmp` | Low
8 | File | `/var/tmp/abrt/*/maps` | High
9 | File | `/var/yp` | Low
10 | File | `action.php` | Medium
11 | File | `add.asp` | Low
12 | File | `add.php` | Low
13 | File | `addinterviewsform.php` | High
14 | File | `admin-files/ad.php` | High
15 | File | `admin.php` | Medium
16 | File | `admin/addsptemplate.php` | High
17 | File | `admin/admin.php` | High
18 | File | `admin/content.php` | High
19 | File | `admin/index.php` | High
20 | File | `admin/membership_pricing.php` | High
21 | File | `admin/picture/picture_real_edit.asp` | High
22 | File | `admin/view.asp` | High
23 | File | `adminfoot.php` | High
24 | File | `administration.php` | High
25 | File | `advertise.php` | High
26 | File | `appl/user_user/server.c` | High
27 | File | `application/classes/application.php` | High
28 | File | `archiv.cgi` | Medium
29 | File | `archive_read_support_format_rar.c` | High
30 | File | `article.asp` | Medium
31 | File | `article.php` | Medium
32 | File | `articles/edit.php` | High
33 | File | `b2archives.php` | High
34 | File | `base/ttinterp.c` | High
35 | File | `bin/defaults/script/info/login.js` | High
36 | File | `board.php` | Medium
37 | File | `categorie.php3` | High
38 | File | `categos.php` | Medium
39 | File | `cgi_test.cgi` | Medium
40 | File | `cms/index.php` | High
41 | File | `CodeBrws.asp` | Medium
42 | File | `coders/mpc.c` | Medium
43 | File | `coders/wmf.c` | Medium
44 | File | `code_generator.php` | High
45 | File | `comm.php` | Medium
46 | ... | ... | ...

There are 396 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2018/12/cryptomining-campaigns-2018.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
