# VertexNet - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [VertexNet](https://vuldb.com/?actor.vertexnet). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.vertexnet](https://vuldb.com/?actor.vertexnet)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with VertexNet:

* [DE](https://vuldb.com/?country.de)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of VertexNet.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.57.226.202](https://vuldb.com/?ip.5.57.226.202) | - | - | High
2 | [18.211.9.206](https://vuldb.com/?ip.18.211.9.206) | ec2-18-211-9-206.compute-1.amazonaws.com | - | Medium
3 | [23.20.239.12](https://vuldb.com/?ip.23.20.239.12) | ec2-23-20-239-12.compute-1.amazonaws.com | - | Medium
4 | [31.170.160.57](https://vuldb.com/?ip.31.170.160.57) | - | - | High
5 | [35.186.238.101](https://vuldb.com/?ip.35.186.238.101) | 101.238.186.35.bc.googleusercontent.com | - | Medium
6 | ... | ... | ... | ...

There are 20 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _VertexNet_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 4 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by VertexNet. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.imwheelrc` | Medium
2 | File | `.jpilot` | Low
3 | File | `.plan` | Low
4 | File | `.tin` | Low
5 | File | `/configs/application.ini` | High
6 | File | `/downloads/` | Medium
7 | File | `/goform/dir_setWanWifi` | High
8 | File | `/proc` | Low
9 | File | `/root/.keeper/` | High
10 | File | `/usr/bin/sonia` | High
11 | File | `3dsimp.cpp` | Medium
12 | File | `Active Browser Profile` | High
13 | File | `admin.asp` | Medium
14 | File | `admin.php` | Medium
15 | File | `admin/stat.ratings.php` | High
16 | File | `aim/icq` | Low
17 | File | `ajax.php` | Medium
18 | File | `akocomment.php` | High
19 | File | `album.php` | Medium
20 | File | `allmanageup.pl` | High
21 | File | `api/device/time` | High
22 | File | `archive_read_support_format_lha.c` | High
23 | File | `ardeaCore/lib/core/ardeaInit.php` | High
24 | File | `arm/lithium-codegen-arm.cc` | High
25 | File | `asm.js` | Low
26 | File | `assetmanager.asp` | High
27 | File | `bar.phtml` | Medium
28 | File | `bb-hostsvc.sh` | High
29 | File | `bible.php` | Medium
30 | File | `bin/named/query.c` | High
31 | File | `blocks.php` | Medium
32 | File | `blog.cgi` | Medium
33 | File | `Calc` | Low
34 | File | `calender.pl` | Medium
35 | File | `cgi-bin/module/sysmanager/admin/SYSAdminUserDialog` | High
36 | File | `cgiforum.pl` | Medium
37 | File | `channels/chan_skinny.c` | High
38 | ... | ... | ...

There are 329 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2019/08/threat-roundup-0823-0830.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
