# CVE-2021-34527 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _CVE-2021-34527_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with CVE-2021-34527:

* [US](https://vuldb.com/?country.us)
* [GB](https://vuldb.com/?country.gb)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 6 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with CVE-2021-34527 or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Russia Unknown](https://vuldb.com/?actor.russia_unknown) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of CVE-2021-34527.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [45.32.137.94](https://vuldb.com/?ip.45.32.137.94) | 45.32.137.94.vultrusercontent.com | [Russia Unknown](https://vuldb.com/?actor.russia_unknown) | High
2 | [157.230.81.39](https://vuldb.com/?ip.157.230.81.39) | - | [Russia Unknown](https://vuldb.com/?actor.russia_unknown) | High
3 | [173.239.198.46](https://vuldb.com/?ip.173.239.198.46) | - | [Russia Unknown](https://vuldb.com/?actor.russia_unknown) | High
4 | ... | ... | ... | ...

There are 1 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within CVE-2021-34527. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 3 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during CVE-2021-34527. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/data/wps.setup.json` | High
3 | File | `/product.php` | Medium
4 | File | `/Pwrchute` | Medium
5 | File | `/uncpath/` | Medium
6 | File | `/WEB-INF/web.xml` | High
7 | File | `admin/web_config.php` | High
8 | File | `adminpanel/modules/pro/inc/ajax.php` | High
9 | File | `admin_add.php` | High
10 | File | `api/v1/User?filterList` | High
11 | File | `apply.cgi` | Medium
12 | File | `avrc_pars_tg.cc` | High
13 | File | `bg_console/index.php?m=opt&c=request` | High
14 | File | `board.php` | Medium
15 | File | `category_list.php` | High
16 | File | `cc_guestbook.pl` | High
17 | File | `coders/png.c` | Medium
18 | ... | ... | ...

There are 143 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://www.cisa.gov/uscert/ncas/alerts/aa22-074a

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
