# CVE-2021-44228 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _CVE-2021-44228_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with CVE-2021-44228:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [DE](https://vuldb.com/?country.de)
* ...

There are 3 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with CVE-2021-44228 or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [APT41](https://vuldb.com/?actor.apt41) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of CVE-2021-44228.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [5.254.101.167](https://vuldb.com/?ip.5.254.101.167) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [37.120.189.247](https://vuldb.com/?ip.37.120.189.247) | support.lgtron.de | [Unknown](https://vuldb.com/?actor.unknown) | High
3 | [41.157.42.239](https://vuldb.com/?ip.41.157.42.239) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
4 | [45.83.64.1](https://vuldb.com/?ip.45.83.64.1) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
5 | [45.83.64.62](https://vuldb.com/?ip.45.83.64.62) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
6 | [45.83.64.103](https://vuldb.com/?ip.45.83.64.103) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
7 | [45.83.64.253](https://vuldb.com/?ip.45.83.64.253) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
8 | ... | ... | ... | ...

There are 28 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within CVE-2021-44228. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1008 | CWE-757 | Algorithm Downgrade | High
2 | T1040 | CWE-294 | Authentication Bypass by Capture-replay | High
3 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 10 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during CVE-2021-44228. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin.php/admin/art/data.html` | High
2 | File | `/admin.php/admin/plog/index.html` | High
3 | File | `/admin.php/admin/ulog/index.html` | High
4 | File | `/admin.php/admin/website/data.html` | High
5 | File | `/admin.php?id=siteoptions&social=display&value=0&sid=2` | High
6 | File | `/admin/inbox.php&action=read` | High
7 | File | `/admin/login.php` | High
8 | File | `/admin/posts.php&action=delete` | High
9 | File | `/admin/siteoptions.php&action=displaygoal&value=1&roleid=1` | High
10 | File | `/admin/uesrs.php&&action=delete&userid=4` | High
11 | File | `/admin/uesrs.php&action=type&userrole=Admin&userid=3` | High
12 | File | `/administrator/components/menu/` | High
13 | File | `/admin_page/all-files-update-ajax.php` | High
14 | File | `/api/crontab` | Medium
15 | File | `/application/common.php#action_log` | High
16 | File | `/category_view.php` | High
17 | File | `/cdsms/classes/Master.php?f=delete_enrollment` | High
18 | File | `/cgi-bin/kerbynet` | High
19 | File | `/cloud_config/router_post/register` | High
20 | File | `/config/list` | Medium
21 | File | `/download/` | Medium
22 | File | `/etc/ajenti/config.yml` | High
23 | File | `/etc/cobbler` | Medium
24 | File | `/etc/passwd` | Medium
25 | File | `/goform/delAd` | High
26 | File | `/goform/form2Reboot.cgi` | High
27 | File | `/home.asp` | Medium
28 | File | `/index.php?act=api&tag=8` | High
29 | File | `/jerry-core/ecma/base/ecma-lcache.c` | High
30 | File | `/jerry-core/ecma/operations/ecma-objects.c` | High
31 | File | `/jerry-core/parser/js/js-scanner-util.c` | High
32 | ... | ... | ...

There are 274 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://isc.sans.edu/forums/diary/Log4Shell+Attacks+Getting+Smarter/28246/
* https://isc.sans.edu/forums/diary/The+Rise+and+Fall+of+log4shell/28372/
* https://pastebin.com/PhnaB0ac
* https://www.mandiant.com/resources/apt41-us-state-governments

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
