# Grand Mars - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Grand Mars_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Grand Mars:

* [DE](https://vuldb.com/?country.de)
* [US](https://vuldb.com/?country.us)
* [GB](https://vuldb.com/?country.gb)
* ...

There are 9 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with Grand Mars or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Carbanak](https://vuldb.com/?actor.carbanak) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Grand Mars.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [62.210.25.121](https://vuldb.com/?ip.62.210.25.121) | svgit.festivalscope.com | [Carbanak](https://vuldb.com/?actor.carbanak) | High
2 | [80.84.49.61](https://vuldb.com/?ip.80.84.49.61) | 61-49-84-80.rackcentre.redstation.net.uk | [Carbanak](https://vuldb.com/?actor.carbanak) | High
3 | [80.84.49.66](https://vuldb.com/?ip.80.84.49.66) | 66-49-84-80.rackcentre.redstation.net.uk | [Carbanak](https://vuldb.com/?actor.carbanak) | High
4 | ... | ... | ... | ...

There are 14 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Grand Mars. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 3 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Grand Mars. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `$HOME/.cdrdao` | High
2 | File | `/cgi-bin/kerbynet` | High
3 | File | `/redbin/rpwebutilities.exe/text` | High
4 | File | `/uncpath/` | Medium
5 | File | `add_comment.php` | High
6 | File | `admin-ajax.php` | High
7 | File | `advertiser.php` | High
8 | File | `ajax/render/widget_php` | High
9 | File | `ardeaCore/lib/core/ardeaInit.php` | High
10 | File | `at/create_job.cgi` | High
11 | File | `aviso.php` | Medium
12 | File | `awstats.pl` | Medium
13 | File | `bar.phtml` | Medium
14 | File | `channeledit.php` | High
15 | File | `chat.php` | Medium
16 | ... | ... | ...

There are 129 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://www.threatminer.org/_reports/2017/OperationGrandMars-Trustwave.pdf#viewer.action=download

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
