# HOPLIGHT - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _HOPLIGHT_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with HOPLIGHT:

* [HK](https://vuldb.com/?country.hk)
* [US](https://vuldb.com/?country.us)
* [JP](https://vuldb.com/?country.jp)
* ...

There are 4 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with HOPLIGHT or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Lazarus](https://vuldb.com/?actor.lazarus) | High
2 | [DPRK](https://vuldb.com/?actor.dprk) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of HOPLIGHT.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [14.140.116.172](https://vuldb.com/?ip.14.140.116.172) | 14-140-116-172-sapient.com | [DPRK](https://vuldb.com/?actor.dprk) | High
2 | [21.252.107.198](https://vuldb.com/?ip.21.252.107.198) | - | [DPRK](https://vuldb.com/?actor.dprk) | High
3 | [26.165.218.44](https://vuldb.com/?ip.26.165.218.44) | - | [DPRK](https://vuldb.com/?actor.dprk) | High
4 | [47.206.4.145](https://vuldb.com/?ip.47.206.4.145) | static-47-206-4-145.srst.fl.frontiernet.net | [DPRK](https://vuldb.com/?actor.dprk) | High
5 | [70.224.36.194](https://vuldb.com/?ip.70.224.36.194) | adsl-70-224-36-194.dsl.sbndin.ameritech.net | [DPRK](https://vuldb.com/?actor.dprk) | High
6 | ... | ... | ... | ...

There are 18 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within HOPLIGHT. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1008 | CWE-757 | Algorithm Downgrade | High
2 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
3 | T1068 | CWE-250, CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
4 | ... | ... | ... | ...

There are 9 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during HOPLIGHT. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/09/business/upgrade/upcfgAction.php?download=true` | High
2 | File | `/admin-panel1.php` | High
3 | File | `/admin/academic/studenview_left.php` | High
4 | File | `/ad_js.php` | Medium
5 | File | `/alerts/alertConfigField.php` | High
6 | File | `/api/email_accounts` | High
7 | File | `/API/system/admins/session` | High
8 | File | `/cgi-bin/ExportALLSettings.sh` | High
9 | File | `/config/config.php` | High
10 | File | `/context/%2e/WEB-INF/web.xml` | High
11 | File | `/customers/index.php` | High
12 | File | `/DataHandler/AM/AM_Handler.ashx` | High
13 | File | `/DataHandler/HandlerAlarmGroup.ashx` | High
14 | File | `/DataHandler/HandlerEnergyType.ashx` | High
15 | File | `/DataHandler/Handler_CFG.ashx` | High
16 | File | `/ECT_Provider/` | High
17 | File | `/fuel/index.php/fuel/logs/items` | High
18 | File | `/fuel/index.php/fuel/pages/items` | High
19 | File | `/goform/openSchedWifi` | High
20 | File | `/goform/SetNetControlList` | High
21 | File | `/image_zoom.php` | High
22 | File | `/include/config.cache.php` | High
23 | File | `/json/profile/removeStarAjax.do` | High
24 | File | `/oauth/token/request` | High
25 | File | `/plugin/ajax.php` | High
26 | File | `/plugins/servlet/branchreview` | High
27 | File | `/proc/ioports` | High
28 | File | `/public/plugins/` | High
29 | File | `/rest/api/2/search` | High
30 | File | `/rest/api/latest/groupuserpicker` | High
31 | File | `/rest/api/latest/projectvalidate/key` | High
32 | File | `/rom-0` | Low
33 | File | `/tmp` | Low
34 | ... | ... | ...

There are 295 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://us-cert.cisa.gov/ncas/analysis-reports/AR19-100A
* https://www.cisa.gov/uscert/ncas/analysis-reports/ar20-045g

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
