# Mandiant - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Mandiant_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Mandiant:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)

## Actors

These _actors_ are associated with Mandiant or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [APT1](https://vuldb.com/?actor.apt1) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Mandiant.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [58.246.0.0](https://vuldb.com/?ip.58.246.0.0) | - | [APT1](https://vuldb.com/?actor.apt1) | High
2 | [58.247.0.0](https://vuldb.com/?ip.58.247.0.0) | - | [APT1](https://vuldb.com/?actor.apt1) | High
3 | [101.80.0.0](https://vuldb.com/?ip.101.80.0.0) | - | [APT1](https://vuldb.com/?actor.apt1) | High
4 | [101.81.0.0](https://vuldb.com/?ip.101.81.0.0) | - | [APT1](https://vuldb.com/?actor.apt1) | High
5 | [101.82.0.0](https://vuldb.com/?ip.101.82.0.0) | - | [APT1](https://vuldb.com/?actor.apt1) | High
6 | [101.83.0.0](https://vuldb.com/?ip.101.83.0.0) | - | [APT1](https://vuldb.com/?actor.apt1) | High
7 | [101.84.0.0](https://vuldb.com/?ip.101.84.0.0) | - | [APT1](https://vuldb.com/?actor.apt1) | High
8 | [101.85.0.0](https://vuldb.com/?ip.101.85.0.0) | - | [APT1](https://vuldb.com/?actor.apt1) | High
9 | [101.86.0.0](https://vuldb.com/?ip.101.86.0.0) | - | [APT1](https://vuldb.com/?actor.apt1) | High
10 | [101.87.0.0](https://vuldb.com/?ip.101.87.0.0) | - | [APT1](https://vuldb.com/?actor.apt1) | High
11 | [101.88.0.0](https://vuldb.com/?ip.101.88.0.0) | - | [APT1](https://vuldb.com/?actor.apt1) | High
12 | [101.89.0.0](https://vuldb.com/?ip.101.89.0.0) | - | [APT1](https://vuldb.com/?actor.apt1) | High
13 | [101.90.0.0](https://vuldb.com/?ip.101.90.0.0) | - | [APT1](https://vuldb.com/?actor.apt1) | High
14 | ... | ... | ... | ...

There are 53 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Mandiant. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79 | Cross Site Scripting | High
2 | T1600 | CWE-310 | Cryptographic Issues | High

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Mandiant. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `login_up.php3` | High
2 | Argument | `login_name` | Medium
3 | Argument | `Password` | Medium

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://www.fireeye.com/content/dam/fireeye-www/services/pdfs/mandiant-apt1-report.pdf

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
