# Phishing Korea - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Phishing Korea_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Phishing Korea:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 8 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with Phishing Korea or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Agent Tesla](https://vuldb.com/?actor.agent_tesla) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Phishing Korea.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [69.174.99.181](https://vuldb.com/?ip.69.174.99.181) | unassigned.quadranet.com | [Agent Tesla](https://vuldb.com/?actor.agent_tesla) | High
2 | [149.56.200.165](https://vuldb.com/?ip.149.56.200.165) | ip165.ip-149-56-200.net | [Agent Tesla](https://vuldb.com/?actor.agent_tesla) | High

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Phishing Korea. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 3 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Phishing Korea. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/cgi-bin/wapopen` | High
3 | File | `/etc/ajenti/config.yml` | High
4 | File | `/goform/telnet` | High
5 | File | `/modules/profile/index.php` | High
6 | File | `/php/init.poll.php` | High
7 | File | `/rom-0` | Low
8 | File | `/tmp/phpglibccheck` | High
9 | File | `/uncpath/` | Medium
10 | File | `/var/tmp/sess_*` | High
11 | File | `action.php` | Medium
12 | File | `actionphp/download.File.php` | High
13 | File | `add_comment.php` | High
14 | File | `admin/admin.php` | High
15 | File | `admin/content.php` | High
16 | File | `admin/index.php?id=users/action=edit/user_id=1` | High
17 | File | `admin/memberviewdetails.php` | High
18 | File | `admin/sitesettings.php` | High
19 | File | `affich.php` | Medium
20 | File | `agent/Core/Controller/SendRequest.cpp` | High
21 | File | `akeyActivationLogin.do` | High
22 | File | `album_portal.php` | High
23 | File | `apache-auth.conf` | High
24 | File | `askapache-firefox-adsense.php` | High
25 | File | `attachment.cgi` | High
26 | File | `basic_search_result.php` | High
27 | File | `blueprints/sections/edit/1` | High
28 | File | `books.php` | Medium
29 | File | `cart_add.php` | Medium
30 | File | `CFS.c` | Low
31 | File | `cgi-bin/gnudip.cgi` | High
32 | File | `checktransferstatus.php` | High
33 | File | `checkuser.php` | High
34 | File | `class.SystemAction.php` | High
35 | File | `clientarea.php` | High
36 | File | `cmdmon.c` | Medium
37 | File | `collectivite.class.php` | High
38 | File | `confirm.php` | Medium
39 | File | `contact` | Low
40 | File | `control.c` | Medium
41 | File | `core-util.c` | Medium
42 | File | `core/coreuserinputhandler.cpp` | High
43 | File | `d1_both.c` | Medium
44 | File | `data/gbconfiguration.dat` | High
45 | File | `Debug_command_page.asp` | High
46 | File | `details_view.php` | High
47 | File | `Diagnose.exe` | Medium
48 | File | `DigiDocSAXParser.c` | High
49 | File | `download-file.php` | High
50 | File | `download.php` | Medium
51 | ... | ... | ...

There are 446 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://www.fortinet.com/blog/threat-research/phishing-campaign-targeting-korean-to-deliver-agent-tesla-new-variant

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
