# Poisoned Hurricane - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Poisoned Hurricane_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Poisoned Hurricane:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [KR](https://vuldb.com/?country.kr)

## Actors

These _actors_ are associated with Poisoned Hurricane or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Poisoned Hurricane](https://vuldb.com/?actor.poisoned_hurricane) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Poisoned Hurricane.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [27.122.13.204](https://vuldb.com/?ip.27.122.13.204) | - | [Poisoned Hurricane](https://vuldb.com/?actor.poisoned_hurricane) | High
2 | [59.125.42.167](https://vuldb.com/?ip.59.125.42.167) | 59-125-42-167.hinet-ip.hinet.net | [Poisoned Hurricane](https://vuldb.com/?actor.poisoned_hurricane) | High
3 | [59.125.42.168](https://vuldb.com/?ip.59.125.42.168) | 59-125-42-168.hinet-ip.hinet.net | [Poisoned Hurricane](https://vuldb.com/?actor.poisoned_hurricane) | High
4 | [61.78.32.139](https://vuldb.com/?ip.61.78.32.139) | - | [Poisoned Hurricane](https://vuldb.com/?actor.poisoned_hurricane) | High
5 | [61.78.32.148](https://vuldb.com/?ip.61.78.32.148) | - | [Poisoned Hurricane](https://vuldb.com/?actor.poisoned_hurricane) | High
6 | [61.78.34.179](https://vuldb.com/?ip.61.78.34.179) | - | [Poisoned Hurricane](https://vuldb.com/?actor.poisoned_hurricane) | High
7 | ... | ... | ... | ...

There are 24 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Poisoned Hurricane. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264 | Execution with Unnecessary Privileges | High

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Poisoned Hurricane. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/shell?cmd` | Medium
2 | File | `HidHostService.java` | High
3 | File | `item_show.php` | High
4 | ... | ... | ...

There are 4 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://unit42.paloaltonetworks.com/attacks-east-asia-using-google-code-command-control/
* https://www.fireeye.com/blog/threat-research/2014/08/operation-poisoned-hurricane.html
* https://www.threatminer.org/report.php?q=Operation_Poisoned_Hurricane.pdf&y=2014

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
