# Potao - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Potao_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Potao:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 12 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with Potao or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Potao](https://vuldb.com/?actor.potao) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Potao.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [5.44.99.46](https://vuldb.com/?ip.5.44.99.46) | server.toastedweb.eu | [Potao](https://vuldb.com/?actor.potao) | High
2 | [37.139.47.162](https://vuldb.com/?ip.37.139.47.162) | 37-139-47-162.vm.clodoserver.ru | [Potao](https://vuldb.com/?actor.potao) | High
3 | [46.163.73.99](https://vuldb.com/?ip.46.163.73.99) | lvps46-163-73-99.dedicated.hosteurope.de | [Potao](https://vuldb.com/?actor.potao) | High
4 | [46.165.228.130](https://vuldb.com/?ip.46.165.228.130) | - | [Potao](https://vuldb.com/?actor.potao) | High
5 | [62.76.42.14](https://vuldb.com/?ip.62.76.42.14) | 62-76-42-14.vm.clodoserver.ru | [Potao](https://vuldb.com/?actor.potao) | High
6 | [62.76.184.245](https://vuldb.com/?ip.62.76.184.245) | 62-76-184-245.vm.clodoserver.ru | [Potao](https://vuldb.com/?actor.potao) | High
7 | [62.76.189.181](https://vuldb.com/?ip.62.76.189.181) | srv.planetaexcel.ru | [Potao](https://vuldb.com/?actor.potao) | High
8 | [64.40.101.43](https://vuldb.com/?ip.64.40.101.43) | - | [Potao](https://vuldb.com/?actor.potao) | High
9 | ... | ... | ... | ...

There are 30 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Potao. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1600 | CWE-310 | Cryptographic Issues | High

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Potao. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/frontend/x3/cpanelpro/filelist-thumbs.html` | High
2 | File | `/htdocs/admin/dict.php?id=3` | High
3 | File | `/iwguestbook/admin/badwords_edit.asp` | High
4 | File | `/setSystemAdmin` | High
5 | File | `/uncpath/` | Medium
6 | File | `/usr/bin/pkexec` | High
7 | File | `/webpages/data` | High
8 | File | `/zm/index.php` | High
9 | ... | ... | ...

There are 61 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://github.com/eset/malware-ioc/tree/master/potao
* https://www.threatminer.org/report.php?q=Operation-Potao-Express_final_v2.pdf&y=2015

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
