# Royal Road - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Royal Road_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Royal Road:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [IT](https://vuldb.com/?country.it)
* ...

There are 13 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with Royal Road or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Royal Road](https://vuldb.com/?actor.royal_road) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Royal Road.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [138.68.133.211](https://vuldb.com/?ip.138.68.133.211) | share.sawblade.org.uk | [Royal Road](https://vuldb.com/?actor.royal_road) | High
2 | [185.216.35.11](https://vuldb.com/?ip.185.216.35.11) | - | [Royal Road](https://vuldb.com/?actor.royal_road) | High
3 | [185.234.73.4](https://vuldb.com/?ip.185.234.73.4) | - | [Royal Road](https://vuldb.com/?actor.royal_road) | High
4 | ... | ... | ... | ...

There are 1 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Royal Road. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 2 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Royal Road. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/bin/sh` | Low
2 | File | `/oauth/authorize` | High
3 | File | `/see_more_details.php` | High
4 | File | `/uncpath/` | Medium
5 | File | `/webmail/` | Medium
6 | File | `/_next` | Low
7 | File | `admin/index.php` | High
8 | File | `assets/add/registrar.php` | High
9 | File | `books.php` | Medium
10 | ... | ... | ...

There are 79 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://www.threatminer.org/report.php?q=MultipleChineseThreatGroupsExploitingCVE-2018-0798EquationEditorVulnerabilitySinceLate2018.pdf&y=2019#gsc.tab=0&gsc.q=MultipleChineseThreatGroupsExploitingCVE-2018-0798EquationEditorVulnerabilitySinceLate2018.pdf&g

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
